@@ -42,7 +42,9 @@ OC.L10N.register(
     "Email address" : "E-posadres",
     "Cancel" : "Kanselleer",
     "Add mail account" : "Voeg posrekening toe",
+    "General" : "Algemeen",
     "Register" : "Registreer",
+    "Keyboard shortcuts" : "Sneltoetse",
     "Archive" : "Argief",
     "Delete" : "Skrap",
     "Search" : "Soek",
@@ -70,17 +72,18 @@ OC.L10N.register(
     "Confirm" : "Bevestig",
     "Plain text" : "Skoonteks",
     "Favorite" : "Gunsteling",
-    "Select" : "Kies",
     "Back" : "Terug",
     "No subject" : "Geen onderwerp",
-    "Forward" : "Stuur aan",
     "All day" : "Heeldag",
     "Description" : "Beskrywing",
     "Create" : "Skep",
+    "Select" : "Kies",
     "Comment" : "Kommentaar",
     "Accept" : "Aanvaar",
+    "Remove" : "Verwyder",
+    "email" : "e-pos",
     "Other" : "Ander",
-    "Reply" : "Antwoord",
+    "Forward" : "Stuur aan",
     "View source" : "Bekyk bron",
     "Message body" : "Boodskaplyfteks",
     "Import into calendar" : "Voer in na kalender",
@@ -94,15 +97,16 @@ OC.L10N.register(
     "New message" : "Nuwe boodskap",
     "Retry" : "Herprobeer",
     "Sending …" : "Stuur…",
+    "Reply" : "Antwoord",
     "Add" : "Voeg by",
     "Date" : "Datum",
     "Tags" : "Etikette",
     "Custom" : "Eie",
     "Message source" : "Boodskapbron",
-    "Remove" : "Verwyder",
+    "Actions" : "Aksies",
+    "Priority" : "Prioriteit",
     "Reset" : "Herstel",
     "Client ID" : "Kliënt-ID",
-    "General" : "Algemeen",
     "User" : "Gebruiker",
     "Host" : "Gasheer",
     "Port" : "Poort",
