@@ -8,40 +8,60 @@ OC.L10N.register(
     "Name" : "Ad",
     "Password" : "Şifrə",
     "None" : "Heç bir",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
     "SMTP Password" : "SMTP Şifrəsi",
     "Save" : "Saxla",
     "Connect" : "Qoşul",
+    "Signature" : "İmza",
     "Cancel" : "Dayandır",
-    "Sending …" : "Göndərilir...",
+    "General" : "Ümumi",
+    "Archive" : "Arxiv",
+    "Delete" : "Sil",
+    "Search" : "Axtarış",
     "Send" : "Göndər",
+    "Refresh" : "Yenilə",
+    "Subject" : "Mövzu",
+    "Enter a date" : "Tarixi əlavə edin",
     "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
+    "Choose" : "Seç",
+    "Confirm" : "Təsdiq edin",
     "Favorite" : "İstəkli",
     "Read" : "Oxu",
-    "Select" : "Select",
-    "Move" : "Move",
+    "Back" : "Geri",
+    "Description" : "Açıqlanma",
     "Create" : "Yarat",
+    "Select" : "Select",
     "Comment" : "Komentariya",
-    "Choose" : "Seç",
-    "Other" : "Digər",
-    "Reply" : "Cavab",
-    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
-    "Quota" : "Norma",
-    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
-    "Clear cache" : "Keşi təmizlə",
-    "Delete" : "Sil",
-    "Add" : "Əlavə etmək",
-    "Disabled" : "Dayandırılıb",
-    "Enabled" : "İşə salınıb",
+    "Accept" : "Qəbul et",
+    "Decline" : "İmtina",
     "Remove" : "Sil",
+    "Other" : "Digər",
+    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
+    "Move" : "Move",
+    "Quota" : "Norma",
+    "Saving" : "Saxlanılır",
+    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
+    "Rename" : "Adı dəyiş",
+    "Clear cache" : "Keşi təmizlə",
+    "Sending …" : "Göndərilir...",
+    "Reply" : "Cavab",
+    "Add" : "Əlavə etmək",
+    "Close" : "Bağla",
+    "Date" : "Date",
+    "Tags" : "Işarələr",
+    "Not found" : "Tapılmadı",
+    "Actions" : "İşlər",
+    "Priority" : "Prioritet",
     "Reset" : "Sıfırla",
-    "General" : "Ümumi",
+    "Client ID" : "Müştəri İD-s",
+    "Client secret" : "Müxtəri sirri",
     "User" : "User",
     "Host" : "Şəbəkədə ünvan",
     "Port" : "Port",
-    "Search" : "Axtarış",
-    "Refresh" : "Yenilə",
+    "Valid until" : "Vaxtadək keçərlidir",
+    "Certificate" : "Sertifikat",
     "All" : "Hamısı",
-    "Archive" : "Arxiv",
     "Drafts" : "Qaralamalar",
     "Favorites" : "Sevimlilər",
     "Inbox" : "Gələn qutusu",
