@@ -10,38 +10,44 @@ OC.L10N.register(
     "None" : "কোনটিই নয়",
     "Save" : "সংরক্ষণ",
     "Connect" : "সংযুক্ত হও",
-    "Cancel" : "বাতির",
-    "Sending …" : "পাঠানো হচ্ছে......",
     "Go back" : "ফিরে যাও",
+    "Cancel" : "বাতির",
+    "General" : "সাধারণ",
+    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
+    "Delete" : "মুছে",
+    "Search" : "Search",
     "Send" : "পাঠাও",
+    "Refresh" : "নবোদ্যম",
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
+    "Choose" : "বেছে নিন",
     "Favorite" : "প্রিয়জন",
     "Read" : "পড়",
-    "Select" : "সিলেক্ট",
     "Edit tags" : "ট্যাগ সম্পাদনা",
-    "Move" : "Move",
+    "Back" : "পেছনে যাও",
+    "Description" : "বিবরণ",
     "Create" : "তৈরী কর",
+    "Select" : "সিলেক্ট",
     "Comment" : "মন্তব্য",
-    "Choose" : "বেছে নিন",
+    "Remove" : "অপসারণ",
     "Other" : "অন্যান্য",
-    "Reply" : "জবাব",
     "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
+    "Move" : "Move",
     "Quota" : "কোটা",
     "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
+    "Rename" : "পূনঃনামকরণ",
     "Clear cache" : "ক্যাশে পরিষ্কার কর",
-    "Delete" : "মুছে",
+    "Sending …" : "পাঠানো হচ্ছে......",
+    "Reply" : "জবাব",
     "Add" : "যোগ করুন",
-    "Search" : "Search",
-    "Disabled" : "অকার্যকর",
-    "Enabled" : "কার্যকর",
-    "Remove" : "অপসারণ",
+    "Close" : "বন্ধ",
+    "Date" : "Date",
+    "Tags" : "ট্যাগ",
+    "Actions" : "পদক্ষেপসমূহ",
     "Reset" : "পূণঃনির্ধানণ",
-    "General" : "সাধারণ",
+    "Client ID" : "ক্লায়েন্ট পরিচিতি",
     "User" : "User",
     "Host" : "হোস্ট",
     "Port" : "পোর্ট",
-    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
-    "Refresh" : "নবোদ্যম",
     "All" : "সবাই",
     "Favorites" : "প্রিয়জন"
 },
