@@ -2,6 +2,7 @@ OC.L10N.register(
     "mail",
     {
     "Important mail" : "Postel pouezus",
+    "Set up an account" : "Staliañ ur c'hont",
     "Work" : "Labour",
     "Personal" : "Personel",
     "Mail" : "Postel",
@@ -13,45 +14,57 @@ OC.L10N.register(
     "SMTP Password" : "Ger-tremen SMTP",
     "Save" : "Enrollañ",
     "Connect" : "Kenstagañ",
+    "Password required" : "Ger-tremen ret",
     "Change name" : "Cheñch env",
     "Cancel" : "Arrest",
-    "Retry" : "Klaskit en dro",
+    "Accounts" : "Kontoù",
+    "General" : "Hollek",
+    "List" : "Roll",
+    "Delete" : "Dilemel",
+    "Search" : "Klask",
     "Send" : "Kas",
-    "Set up an account" : "Staliañ ur c'hont",
+    "Refresh" : "Freskaat",
+    "Choose" : "Dibab",
+    "Confirm" : "Kadarnañ",
     "Unfavorite" : "Digaretañ",
     "Favorite" : "Pennrollañ",
-    "Unselect" : "Dizibab",
-    "Select" : "Dibab",
-    "Move" : "Diplasañ",
-    "Forward" : "War-raok",
+    "Back" : "Distro",
+    "Description" : "Deskrivadur",
     "Create" : "Krouiñ",
+    "Select" : "Dibab",
     "Comment" : "Displegadenn",
     "Accept" : "Asantiñ",
-    "Choose" : "Dibab",
+    "Remove" : "Lemel",
+    "email" : "postel",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
-    "Reply" : "Respont",
+    "Forward" : "War-raok",
     "Show images" : "Diskouzh ar skeudennoù",
     "Message frame" : "Fram kemenadenn",
+    "Move" : "Diplasañ",
     "Quota" : "Quota",
     "Remove account" : "Lemel ar c'hont",
     "Loading …" : "O Kargañ ...",
-    "Edit name" : "Ebmann anv",
+    "Rename" : "Adenvel",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
-    "Delete" : "Dilemel",
+    "Retry" : "Klaskit en dro",
+    "Reply" : "Respont",
     "Add" : "Ouzhpennañ",
-    "Search" : "Klask",
-    "Disabled" : "Disaotreañ",
-    "Enabled" : "Aotreet",
-    "Unset" : "N'eo ket bet lakaet",
-    "Remove" : "Lemel",
-    "General" : "Hollek",
+    "Close" : "Serriñ",
+    "Date" : "Deiz",
+    "Tags" : "Klavioù",
+    "Clear" : "Netaat",
+    "Actions" : "Oberoù",
+    "Client ID" : "ID kliant",
     "User" : "Implijer",
     "Host" : "Ostiz",
     "Port" : "Porzh",
-    "Refresh" : "Freskaat",
+    "Valid until" : "Gwir betek",
+    "Submit" : "Kinnig",
+    "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
+    "Unselect" : "Dizibab"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
