@@ -3,14 +3,16 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ενσωματωμένο μήνυμα %s",
     "Important mail" : "Σημαντική αλληλογραφία",
+    "No message found yet" : "Δε βρέθηκε μήνυμα ακόμη.",
+    "Set up an account" : "Ρυθμίστε ένα λογαριασμό",
     "Unread mail" : "Μη αναγνωσμένη αλληλογραφία",
     "Important" : "Σημαντικό ",
     "Work" : "Εργασία",
     "Personal" : "Προσωπικό",
     "To Do" : "Προς Ενέργεια",
     "Later" : "Αργότερα",
-    "Mails" : "Ηλ.Αλληλογραφία",
     "Mail" : "Αλληλογραφία",
+    "Mails" : "Ηλ.Αλληλογραφία",
     "💌 A mail app for Nextcloud" : "Εφαρμογή ηλ.ταχυδρομείου για το Nextcloud",
     "Drafts are saved in:" : "Τα πρόχειρα αποθηκεύονται σε:",
     "Sent messages are saved in:" : "Τα απεσταλμένα μηνύματα αποθηκεύονται σε:",
@@ -38,9 +40,10 @@ OC.L10N.register(
     "SMTP User" : "Χρήστης SMTP",
     "SMTP Password" : "Συνθηματικό SMTP",
     "Connecting" : "Συνδέεται",
+    "Sign in with Google" : "Σύνδεση με την Google",
     "Save" : "Αποθήκευση",
     "Connect" : "Σύνδεση",
-    "Account created" : "Ο λογαριασμός δημιουργήθηκε",
+    "Password required" : "Απαιτείται συνθηματικό",
     "IMAP server is not reachable" : "Ο διακομιστής IMAP δεν είναι προσβάσιμος",
     "SMTP server is not reachable" : "Ο διακομιστής SMTP δεν είναι προσβάσιμος",
     "SMTP username or password is wrong" : "Το όνομα χρήστη ή ο κωδικός πρόσβασης SMTP είναι λάθος",
@@ -48,30 +51,49 @@ OC.L10N.register(
     "SMTP connection failed" : "Η σύνδεση SMTP απέτυχε",
     "There was an error while setting up your account" : "Παρουσιάστηκε σφάλμα κατά τη ρύθμιση του λογαριασμού σας",
     "Account settings" : "Ρυθμίσεις λογαριασμού",
-    "Change name" : "Αλλαγή ονόματος",
+    "Aliases" : "Ψευδώνυμα",
     "Signature" : "Υπογραφή",
     "A signature is added to the text of new messages and replies." : "Μια υπογραφή προστίθεται στο κείμενο των νέων μηνυμάτων και των απαντήσεων.",
     "Writing mode" : "Κατάσταση επεξεργασίας",
     "Preferred writing mode for new messages and replies." : "Προτιμώμενη λειτουργία σύνταξης για νέα μηνύματα και απαντήσεις.",
     "Default folders" : "Προεπιλεγμένοι φάκελοι",
-    "The folders to use for drafts, sent messages, deleted messages and archived messages." : "Οι φάκελοι που θα χρησιμοποιηθούν για πρόχειρα, απεσταλμένα, διαγραμμένα και αρχειοθετημένα μηνύματα.",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Αυτοματοποιημένη απάντηση σε εισερχόμενα μηνύματα. Εάν κάποιος σας στείλει πολλά μηνύματα, αυτή η αυτοματοποιημένη απάντηση θα αποστέλλεται το πολύ μία φορά κάθε 4 ημέρες.",
-    "Trusted senders" : "Έμπιστοι αποστολείς",
+    "Filters" : "Φίλτρα",
     "Mail server" : "Διακομιστής αλληλογραφίας",
     "Update alias" : "Ενημέρωση ψευδώνυμου",
     "Show update alias form" : "Εμφάνιση φόρμας ενημέρωσης ψευδώνυμου",
     "Delete alias" : "Διαγραφή ψευδωνύμου",
+    "Go back" : "Πίσω",
+    "Change name" : "Αλλαγή ονόματος",
     "Email address" : "Διεύθυνση αλληλογραφίας",
     "Add alias" : "Προσθήκη alias",
     "Create alias" : "Δημιουργία ψευδωνύμου",
     "Cancel" : "Ακύρωση",
+    "Mail settings" : "Ρυθμίσεις αλληλογραφίας",
+    "Accounts" : "Λογαριασμοί",
     "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
+    "General" : "Γενικά",
+    "List" : "Λίστα",
+    "Sorting" : "Ταξινόμηση",
+    "Newest" : "Νεότερο",
+    "Oldest" : "Παλαιότερο",
     "Use Gravatar and favicon avatars" : "Χρησιμοποιήστε Gravatar και favicon avatars",
     "Register as application for mail links" : "Εγγραφή ως εφαρμογή για συνδέσμους αλληλογραφίας",
-    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
+    "Register" : "Εγγραφή",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Να επιτρέπεται στην εφαρμογή να συλλέγει δεδομένα σχετικά με την δραστηριότητά σας. Με βάση αυτά τα δεδομένα, η εφαρμογή θα προσαρμοστεί στις προτιμήσεις σας. Τα δεδομένα θα αποθηκευτούν μόνο τοπικά.",
+    "Trusted senders" : "Έμπιστοι αποστολείς",
+    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
+    "Compose new message" : "Σύνταξη νέου μηνύματος",
+    "Newer message" : "Νεότερο μήνυμα",
+    "Older message" : "Παλαιότερο μήνυμα",
+    "Toggle star" : "Εναλλαγή αστεριού",
+    "Toggle unread" : "Εναλλαγή αδιάβαστων",
+    "Archive" : "Αρχειοθετημένα",
+    "Delete" : "Διαγραφή",
+    "Search" : "Αναζήτηση",
+    "Send" : "Αποστολή",
+    "Refresh" : "Ανανέωση",
     "Put my text to the bottom of a reply instead of on top of it." : "Το κείμενό μου στο κάτω μέρος μιας απάντησης αντί στο επάνω μέρος της.",
-    "Automatically classify importance of new email" : "Αυτόματη ταξινόμηση σπουδαιότητας νέων email",
     "Could not update preference" : "Δεν ήταν δυνατή η ενημέρωση της προτίμησης",
     "From" : "Από:",
     "Select account" : "Επιλογή λογαριασμού",
@@ -79,7 +101,6 @@ OC.L10N.register(
     "Contact or email address …" : "Επαφή ή διεύθυνση ηλ.ταχυδρομείου ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Δε βρέθηκαν επαφές.",
     "Subject" : "Θέμα",
     "Subject …" : "Θέμα...",
     "This message came from a noreply address so your reply will probably not be read." : "Η αλληλογραφία προέρχεται από διεύθυνση η οποία δεν δέχεται απαντήσεις, οπότε η απάντησή σας πιθανότατα δεν θα διαβαστεί.",
@@ -90,10 +111,10 @@ OC.L10N.register(
     "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
     "Save draft" : "Αποθήκευση ως πρόχειρο",
     "Discard & close draft" : "Απόρριψη & κλείσιμο πρόχειρου",
+    "Enable formatting" : "Ενεργοποίηση μορφοποίησης",
     "Upload attachment" : "Μεταφόρτωση συνημμένων",
     "Add attachment from Files" : "Προσθήκη συνημμένου από Αρχεία",
     "Send later" : "Αποστολή αργότερα",
-    "Enable formatting" : "Ενεργοποίηση μορφοποίησης",
     "Request a read receipt" : "Ζητήστε βεβαίωση ανάγνωσης",
     "Encrypt message with Mailvelope" : "Κρυπτογράφηση μηνύματος με το Mailvelope",
     "Send now" : "Αποστολή τωρα",
@@ -102,30 +123,16 @@ OC.L10N.register(
     "Monday morning" : "Δευτέρα πρωί",
     "Custom date and time" : "Επιλέξτε ημερομηνία και ώρα",
     "Enter a date" : "Προσθέστε ημερομηνία",
-    "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
-    "Sending …" : "Γίνεται αποστολή...",
-    "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
-    "Go back" : "Πίσω",
-    "Retry" : "Δοκιμή ξανά",
-    "Send anyway" : "Στείλτε ούτως ή άλλως",
-    "Message sent!" : "Μήνυμα εστάλη!",
-    "Add share link from {productName} Files" : "Προσθήκη συνδέσμου κοινής χρήσης από αρχεία {productName}",
-    "Send" : "Αποστολή",
-    "Encrypt and send" : "Κρυπτογράφηση και αποστολή",
-    "Send unencrypted" : "Αποστολή μη κρυπτογραφημένου",
     "Message {id} could not be found" : "Δεν ήταν δυνατή η εύρεση του μηνύματος {id}",
-    "No sent mailbox configured. Please pick one in the account settings." : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο για τα απεσταλμένα μηνύματα. Επιλέξτε ένα από τις ρυθμίσεις λογαριασμού.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Προσπαθείτε να στείλετε σε πολλούς παραλήπτες σε Προς και/ή Κοιν. Εξετάστε το ενδεχόμενο να χρησιμοποιήσετε Κρυφή κοιν. για να αποκρύψετε τις διευθύνσεις παραληπτών.",
     "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
     "Choose a file to share as a link" : "Επιλέξτε ένα αρχείο για κοινή χρήση ως σύνδεσμο",
+    "Choose" : "Επιλογή",
     "_{count} attachment_::_{count} attachments_" : ["{count} συνημμένo","{count} συνημμένα"],
-    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Το συνημμένο υπερβαίνει το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε το αρχείο μέσω συνδέσμου.","Τα συνημμένα υπερβαίνουν το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε τα αρχεία μέσω συνδέσμου."],
-    "No message found yet" : "Δε βρέθηκε μήνυμα ακόμη.",
-    "Set up an account" : "Ρυθμίστε ένα λογαριασμό",
+    "Confirm" : "Επιβεβαίωση",
     "Plain text" : "Απλό κείμενο",
     "Rich text" : "Εμπλουτισμένο κείμενο",
     "No messages in this mailbox" : "Δεν υπάρχουν μηνύματα σε αυτό το γραμματοκιβώτιο.",
-    "Messages marked as important will show up here" : "Εδώ θα εμφανίζονται τα μηνύματα που έχουν επισημανθεί ως σημαντικά",
+    "No messages" : "Κανένα μήνυμα",
     "Draft: " : "Πρόχειρο:",
     "Unfavorite" : "Μη αγαπημένο",
     "Favorite" : "Αγαπημένο",
@@ -134,25 +141,27 @@ OC.L10N.register(
     "Unimportant" : "Μη σημαντικό",
     "Mark not spam" : "Σήμανση ως μη ανεπιθύμητο",
     "Mark as spam" : "Σήμανση ως ανεπιθύμητο",
-    "Unselect" : "Αναίρεση επιλογής",
-    "Select" : "Επιλογή",
     "Edit tags" : "Επεξεργασία ετικετών",
-    "Move" : "Μετακίνηση",
     "Move thread" : "Μετακίνηση νήματος",
     "Delete thread" : "Διαγραφή νήματος",
     "More actions" : "Περισσότερες ενέργειες",
+    "Back" : "Πίσω",
     "Edit as new message" : "Επεξεργασία ως νέο μήνυμα",
     "Create event" : "Δημιουργία συμβάντος",
+    "Create task" : "Δημιουργία εργασίας",
     "Download message" : "Λήψη μηνύματος",
     "Blind copy recipients only" : "Αποδέκτες με κρυφή κοινοποίηση μόνο",
     "No subject" : "Χωρίς θέμα",
+    "Set reminder for later today" : "Ορισμός υπενθύμισης για αργότερα σήμερα",
+    "Set reminder for tomorrow" : "Ορισμός υπενθύμισης για αύριο",
+    "Set reminder for this weekend" : "Ορίστε υπενθύμιση για αυτό το Σαββατοκύριακο",
+    "Set reminder for next week" : "Ορίστε υπενθύμιση για την επόμενη εβδομάδα",
     "No trash mailbox configured" : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο απορριμμάτων",
     "Could not delete message" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος",
     "Could not archive message" : "Δεν ήταν δυνατή η αρχειοθέτηση του μηνύματος",
-    "Forward" : "Προώθηση",
     "Load more" : "Φόρτωση περισσότερων",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["Επισήμανση {number} ως μη αναγνωσμένου","Επισήμανση {number} ως μη αναγνωσμένων"],
     "_Mark {number} read_::_Mark {number} read_" : ["Επισήμανση {number} ως αναγνωσμένου","Επισήμανση {number} ως αναγνωσμένων"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Επισήμανση {number} ως μη αναγνωσμένου","Επισήμανση {number} ως μη αναγνωσμένων"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Επισήμανση {number} ως σημαντικού","Επισήμανση {number} ως σημαντικών"],
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Επισήμανση {number} ως μη σημαντικού","Επισήμανση {number} ως μη σημαντικών"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Μη αγαπημένο {number}","Μη αγαπημένα {number}"],
@@ -160,9 +169,9 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Αναίρεση επιλογής {number}","Αναίρεση επιλογών {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Μετακίνηση {number} νημάτος","Μετακίνηση {number} νημάτων"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Προώθηση {number} ως συνημμένο","Προώθηση {number} ως συνημμένων"],
-    "_Delete {number} thread_::_Delete {number} threads_" : ["Διαγραφή {number} νημάτος","Διαγραφή {number} νημάτων"],
     "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
     "All day" : "Ολοήμερο",
+    "Description" : "Περιγραφή",
     "Create" : "Δημιουργία",
     "Event created" : "Το συμβάν δημιουργήθηκε",
     "Could not create event" : "Αδυναμία δημιουργίας συμβάντος",
@@ -173,6 +182,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Έχετε προσκληθεί σε μια εκδήλωση",
     "This event was cancelled" : "Αυτή η εκδήλωση ακυρώθηκε",
     "Save to" : "Αποθήκευση σε",
+    "Select" : "Επιλογή",
     "Comment" : "Σχόλιο",
     "Accept" : "Αποδοχή",
     "Decline" : "Απόρριψη",
@@ -180,12 +190,15 @@ OC.L10N.register(
     "More options" : "Περισσότερες επιλογές",
     "This event is in the past." : "Αυτή η εκδήλωση ανήκει στο παρελθόν.",
     "This event was updated" : "Αυτή η εκδήλωση ενημερώθηκε",
+    "domain" : "τομέας",
+    "Remove" : "Αφαίρεση",
+    "email" : "Ηλ.Ταχυδρομείο",
+    "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
     "Could not open mailbox" : "Δεν ήταν δυνατό το άνοιγμα του γραμματοκιβωτίου",
     "Loading messages …" : "Φόρτωση μηνυμάτων ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Καταλογοποίηση των μηνυμάτων σας. Αυτό μπορεί να διαρκέσει περισσότερο για μεγαλύτερα γραμματοκιβώτια.",
     "Choose target mailbox" : "Επιλέξτε γραμματοκιβώτιο προορισμού",
     "No more submailboxes in here" : "Δεν υπάρχουν άλλα υπο-γραμματοκιβώτια εδώ",
-    "Choose" : "Επιλογή",
     "Important info" : "Σημαντική πλροφορία",
     "Other" : "Άλλο",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Τα μηνύματα θα επισημανθούν αυτόματα ως σημαντικά με βάση αυτά με τα οποία επισημαίνετε ως σημαντικά. Στην αρχή ίσως χρειαστεί να τα αλλάζετε χειροκίνητα, έως ότου εκπαιδευτεί το σύστημα, αλλά θα βελτιώνεται σταδιακά με την πάροδο του χρόνου.",
@@ -193,24 +206,21 @@ OC.L10N.register(
     "Notify the sender" : "Ειδοποιήστε τον αποστολέα",
     "You sent a read confirmation to the sender of this message." : "Στείλατε βεβαίωση ανάγνωσης στον αποστολέα του μηνύματος.",
     "Could not send mdn" : "Αδυναμία αποστολής mdn",
-    "Reply all" : "Απάντηση σε όλους",
-    "Reply" : "Απάντηση",
-    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
+    "Forward" : "Προώθηση",
     "Move message" : "Μετακίνηση μηνύματος",
     "Forward message as attachment" : "Προώθηση μηνύματος ως συνημμένο",
     "View source" : "Προβολή πηγής",
     "Download thread data for debugging" : "Λήψη δεδομένων νήματος ακολουθίας για εντοπισμό σφαλμάτων",
-    "Message source" : "Πηγή μηνύματος",
     "Message body" : "Σώμα μηνύματος",
+    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
     "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
     "Download attachment" : "Λήψη συνημμένου",
     "Save to Files" : "Αποθήκευση στα Αρχεία",
     "Unnamed" : "Ανώνυμο",
     "Embedded message" : "Ενσωματωμένο μήνυμα",
-    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
+    "Choose a folder to store the attachments in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε μέσα τα συνημμένα",
     "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
     "Download Zip" : "Λήψη Zip",
-    "Choose a folder to store the attachments in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε μέσα τα συνημμένα",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Το μήνυμα είναι κρυπτογραφημένο με PGP. Εγκαταστήστε το Mailvelope για αποκρυπτογράφηση.",
     "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
     "Show images" : "Εμφάνιση εικόνων",
@@ -219,10 +229,10 @@ OC.L10N.register(
     "Always show images from {domain}" : "Εμφάνιση πάντα εικόνων από {domain}",
     "Message frame" : "Πλαίσιο κειμένου",
     "Quoted text" : "Κείμενο σε παράθεση",
+    "Move" : "Μετακίνηση",
     "Moving" : "Μετακινείται",
     "Moving thread" : "Μετακίνηση νήματος",
     "Moving message" : "Μετακίνηση μηνύματος",
-    "Mail settings" : "Ρυθμίσεις αλληλογραφίας",
     "Quota" : "Σύνολο χώρου",
     "Show only subscribed mailboxes" : "Εμφάνιση μόνο εγγεγραμμένων γραμματοκιβωτίων",
     "Add mailbox" : "Προσθήκη γραμματοκιβωτίου",
@@ -234,7 +244,6 @@ OC.L10N.register(
     "Not supported by the server" : "Δεν υποστηρίζεται από τον διακομιστή",
     "{usage} of {limit} used" : "Σε χρήση {usage} από {limit}",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Ο λογαριασμός για {email} και προσωρινά αποθηκευμένα δεδομένα email θα καταργηθεί από το Nextcloud, αλλά όχι από τον πάροχο email σας.",
-    "Remove account {email}" : "Αφαίρεση λογαριασμού {email}",
     "Remove {email}" : "Αφαίρεση {email}",
     "Show all subscribed mailboxes" : "Εμφάνιση όλων των εγγεγραμμένων γραμματοκιβωτίων",
     "Show all mailboxes" : "Εμφάνιση όλων των γραμματοκιβωτίων",
@@ -242,7 +251,7 @@ OC.L10N.register(
     "Mark all as read" : "Σημείωση όλων ως αναγνωσμένων",
     "Mark all messages of this mailbox as read" : "Επισήμανση όλων ως αναγνωσμένων",
     "Add submailbox" : "Προσθήκη υπο-γραμματοκιβωτίου",
-    "Edit name" : "Επεξεργασία ονόματος",
+    "Rename" : "Μετονομασία",
     "Clear cache" : "Εκκαθάριση προσωρινής μνήμης",
     "Clear locally cached data, in case there are issues with synchronization." : "Εκκαθαρίστε τα δεδομένα κρυφής μνήμης, σε περίπτωση που υπάρχουν προβλήματα με το συγχρονισμό.",
     "Subscribed" : "Εγγεγραμμένα",
@@ -252,18 +261,23 @@ OC.L10N.register(
     "Delete mailbox {name}" : "Διαγραφή γραμματοκιβωτίου {name}",
     "An error occurred, unable to rename the mailbox." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία του γραμματοκιβωτίου.",
     "_{total} message_::_{total} messages_" : ["{total} μήνυμα","{total} μηνύματα"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} μη αναγνωσμένο από {total}","{unread} μη αναγνωσμένα από {total}"],
     "Outbox" : "Εξερχόμενα",
     "New message" : "Νέο μήνυμα",
+    "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
+    "Retry" : "Δοκιμή ξανά",
+    "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
+    "Sending …" : "Γίνεται αποστολή...",
+    "Send anyway" : "Στείλτε ούτως ή άλλως",
     "Edit message" : "Επεξεργασία μηνύματος",
     "Draft" : "Πρόχειρο",
+    "Reply" : "Απάντηση",
+    "No sent mailbox configured. Please pick one in the account settings." : "Δεν έχει διαμορφωθεί γραμματοκιβώτιο για τα απεσταλμένα μηνύματα. Επιλέξτε ένα από τις ρυθμίσεις λογαριασμού.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Προσπαθείτε να στείλετε σε πολλούς παραλήπτες σε Προς και/ή Κοιν. Εξετάστε το ενδεχόμενο να χρησιμοποιήσετε Κρυφή κοιν. για να αποκρύψετε τις διευθύνσεις παραληπτών.",
     "Message discarded" : "Το μήνυμα απορρίφθηκε",
     "Could not discard message" : "Δεν ήταν δυνατή η απόρριψη του μηνύματος",
-    "No message selected" : "Κανένα μήνυμα δεν επελέγη",
     "Message" : "Μήνυμα",
     "Could not open outbox" : "Αδυναμία ανοίγματος εξερχομένων",
     "Pending or not sent messages will show up here" : "Εδώ εμφανίζονται μηνύματα που εκκρεμούν ή δεν έχουν σταλεί",
-    "Delete" : "Διαγραφή",
     "Message could not be sent" : "Δεν ήταν δυνατή η αποστολή του μηνύματος",
     "Message deleted" : "Το μήνυμα διαγράφτηκε",
     "Contacts with this address" : "Επαφές με αυτήν τη διεύθυνση",
@@ -272,31 +286,35 @@ OC.L10N.register(
     "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
     "Contact name …" : "Όνομα επαφής ...",
     "Add" : "Προσθήκη",
-    "Search" : "Αναζήτηση",
-    "Disabled" : "Απενεργοποιημένο",
-    "Enabled" : "Ενεργοποιημένο",
-    "IMAP Credentials" : "Διαπιστευτήρια IMAP",
+    "Close" : "Κλείσιμο",
+    "Body" : "Σώμα",
+    "Date" : "Ημερομηνία",
+    "Tags" : "Ετικέτες",
+    "Select tags" : "Επιλέξτε ετικέτες",
+    "Last 7 days" : "Τελευταίες 7 ημέρες",
+    "Clear" : "Εκκαθάριση",
     "Custom" : "Προσαρμοσμένο",
     "Sieve User" : "Χρήστης Sieve",
     "Signature …" : "Υπογραφή...",
     "Save signature" : "Αποθήκευση υπογραφής",
-    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
-    "Rename tag" : "Μετονομασία ετικέτας",
     "Saving new tag name …" : "Αποθήκευση νέου ονόματος ετικέτας…",
-    "Set" : "Ορισμός",
-    "Unset" : "Απενεργοποίηση",
+    "Delete tag" : "Διαγραφή ετικέτας",
+    "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
+    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
     "Add tag" : "Προσθήκη ετικέτας",
     "Saving tag …" : "Αποθήκευση ετικέτας…",
     "Tag already exists" : "Υπάρχει ήδη η ετικέτα",
     "An error occurred, unable to create the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία της ετικέτας.",
-    "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
+    "Not found" : "Δε βρέθηκε",
     "Could not load your message thread" : "Δεν ήταν δυνατή η φόρτωση του μηνύματός σας",
+    "Unsubscribe" : "Κατάργηση εγγραφής",
+    "Reply all" : "Απάντηση σε όλους",
+    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
     "Mark as favorite" : "Επισήμανση ως αγαπημένο",
     "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
     "Mark as read" : "Σήμανση ως αναγνωσμένο",
     "Delete message" : "Διαγραφή μηνύματος",
-    "Not found" : "Δε βρέθηκε",
-    "Remove" : "Αφαίρεση",
+    "Message source" : "Πηγή μηνύματος",
     "No senders are trusted at the moment." : "Κανένας αποστολέας δεν είναι αξιόπιστος αυτή τη στιγμή.",
     "Could not remove trusted sender {sender}" : "Δεν ήταν δυνατή η κατάργηση του αξιόπιστου αποστολέα {sender}",
     "(organizer)" : "(organizer)",
@@ -309,33 +327,37 @@ OC.L10N.register(
     "Train" : "Τρένο",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} από {depStation} προς {arrStation}",
     "Train from {depStation} to {arrStation}" : "Τρένο από {depStation} προς {arrStation}",
+    "Delete filter" : "Διαγραφή φίλτρου",
+    "Operator" : "Διαχειριστής",
+    "Actions" : "Ενέργειες",
+    "Priority" : "Προτεραιότητα",
     "Mail app" : "Εφαρμογή αλληλογραφίας",
     "The mail app allows users to read mails on their IMAP accounts." : "Η εφαρμογή ταχυδρομείου επιτρέπει στους χρήστες να διαβάζουν μηνύματα από τους λογαριασμούς τους IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Εδώ μπορείτε να βρείτε ρυθμίσεις για το περιστατικό. Οι συγκεκριμένες ρυθμίσεις χρήστη βρίσκονται στην ίδια την εφαρμογή (κάτω αριστερή γωνία).",
     "Reset" : "Επαναφορά",
+    "Client ID" : "Αναγνωριστικό πελάτη",
+    "Client secret" : "Μυστικό πελάτη",
+    "Unlink" : "Αποσύνδεση",
     "Email: {email}" : "Email: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} σε {host}:{port} ({ssl} encryption)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} σε {host}:{port} ({ssl} encryption)",
-    "General" : "Γενικά",
     "IMAP" : "IMAP",
     "User" : "Χρήστης",
     "Host" : "Διακομιστής",
     "Port" : "Θύρα",
     "SMTP" : "SMTP",
     "With the settings above, the app will create account settings in the following way:" : "Με τις παραπάνω ρυθμίσεις, η εφαρμογή θα δημιουργήσει τις ρυθμίσεις λογαριασμού με τον ακόλουθο τρόπο:",
-    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
-    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
-    "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
-    "Compose new message" : "Σύνταξη νέου μηνύματος",
-    "Newer message" : "Νεότερο μήνυμα",
-    "Older message" : "Παλαιότερο μήνυμα",
-    "Toggle star" : "Εναλλαγή αστεριού",
-    "Toggle unread" : "Εναλλαγή αδιάβαστων",
-    "Refresh" : "Ανανέωση",
+    "E-mail address" : "E-mail διεύθυνση",
+    "Valid until" : "Έγκυρο έως",
+    "Certificate" : "Πιστοποιητικό",
+    "Submit" : "Υποβολή",
+    "Account connected" : "Συνδεδεμένος λογαριασμός",
     "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
-    "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
+    "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
+    "This weekend – {timeLocale}" : "Αυτή την εβδομάδα – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
+    "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
     "All" : "'Ολα",
-    "Archive" : "Αρχειοθετημένα",
     "Drafts" : "Πρόχειρα",
     "Favorites" : "Αγαπημένα",
     "Priority inbox" : "Εισερχόμενα προτεραιότητας",
@@ -361,6 +383,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
-    "Continue to %s" : "Συνέχεια στο %s"
+    "Continue to %s" : "Συνέχεια στο %s",
+    "Unselect" : "Αναίρεση επιλογής"
 },
 "nplurals=2; plural=(n != 1);");
