@@ -6,8 +6,8 @@ OC.L10N.register(
     "Work" : "Laboro",
     "Personal" : "Persona",
     "Later" : "Poste",
-    "Mails" : "Retpoŝtoj",
     "Mail" : "Retpoŝtilo",
+    "Mails" : "Retpoŝtoj",
     "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
     "Auto" : "Aŭtomate",
     "Name" : "Nomo",
@@ -31,100 +31,116 @@ OC.L10N.register(
     "Connecting" : "Konektante",
     "Save" : "Konservi",
     "Connect" : "Konekti",
+    "Password required" : "Pasvorto bezonata",
     "Account settings" : "Kontaj agordoj",
-    "Change name" : "Ŝanĝi nomon",
     "Signature" : "Subskribo",
     "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
     "Writing mode" : "Skribreĝimo",
     "Preferred writing mode for new messages and replies." : "Prefera skribreĝimo por novaj mesaĝoj kaj respondoj.",
     "Mail server" : "Retpoŝtoservilo",
+    "Go back" : "Reveni",
+    "Change name" : "Ŝanĝi nomon",
     "Email address" : "Retpoŝtadreso",
     "Cancel" : "Nuligi",
+    "Accounts" : "Kontoj",
     "Add mail account" : "Aldoni retpoŝtan konton",
+    "General" : "Ĝenerala",
     "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
     "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
+    "Register" : "Registriĝi",
+    "Keyboard shortcuts" : "Fulmoklavoj",
+    "Compose new message" : "Krei novan mesaĝon",
+    "Newer message" : "Pli nova mesaĝo",
+    "Older message" : "Pli malnova mesaĝo",
+    "Toggle star" : "Baskuligi stelon",
+    "Toggle unread" : "Baskuligi legostaton",
+    "Archive" : "Arĥivujo",
+    "Delete" : "Forigi",
+    "Search" : "Serĉi",
+    "Send" : "Sendi",
+    "Refresh" : "Aktualigi",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
     "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
-    "No contacts found." : "Neniuj kontaktoj trovitaj.",
     "Subject" : "Temo",
     "Subject …" : "Temo …",
     "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
     "Write message …" : "Verku mesaĝon …",
     "Saving draft …" : "Konservado de malneto...",
     "Draft saved" : "Malneto konservita",
+    "Enable formatting" : "Ebligi formatado",
     "Upload attachment" : "Alŝuti kunsendaĵon",
     "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
-    "Enable formatting" : "Ebligi formatado",
     "Enter a date" : "Entajpu daton",
-    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
-    "Sending …" : "Sendado...",
-    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
-    "Go back" : "Reveni",
-    "Retry" : "Reprovi",
-    "Message sent!" : "Mesaĝo sendiĝis!",
-    "Send" : "Sendi",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
+    "Choose" : "Elekti",
+    "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
     "Draft: " : "Malneto:",
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
     "Read" : "Legi",
-    "Unselect" : "Malelekti",
-    "Select" : "Elekti",
     "Edit tags" : "Redakti etikedojn",
-    "Move" : "Movi",
     "More actions" : "Pliaj agoj",
+    "Back" : "Antaŭen",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
-    "Forward" : "Antaŭen",
     "Report this bug" : "Raporti tiun problemon",
     "All day" : "Tuttage",
+    "Description" : "Priskribo",
     "Create" : "Krei",
     "Could not create event" : "Ne eblis krei okazaĵon",
+    "Select" : "Elekti",
     "Comment" : "Komento",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
+    "Remove" : "Forigi",
+    "email" : "retpoŝtadreso",
     "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
-    "Choose" : "Elekti",
     "Other" : "Alia",
-    "Reply" : "Respondi",
-    "Reply to sender only" : "Respondi nur al sendinto",
+    "Forward" : "Antaŭen",
+    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
     "Save to Files" : "Konservi en „Dosieroj“",
     "Unnamed" : "Nenomita",
     "Embedded message" : "Enkorpiga mesaĝo",
-    "Choose a folder to store the attachment in" : "Elektu dosierujon en kiu konservi la kunsendaĵon",
-    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "Choose a folder to store the attachments in" : "Elektu dosierujon en kiu konservi la kunsendaĵojn",
+    "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
+    "Move" : "Movi",
     "Quota" : "Kvoto",
     "Saving" : "Konservado",
     "Move down" : "Movi malsupren",
     "Remove account" : "Forigi konton",
     "Loading …" : "Ŝargas …",
     "Mark all as read" : "Marki ĉion kiel legita",
+    "Rename" : "Alinomi",
     "Clear cache" : "Forviŝi la kaŝmemoron",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "New message" : "Nova mesaĝo",
-    "No message selected" : "Neniu mesaĝo elektita",
+    "Error sending your message" : "Eraro dum sendo de via mesaĝo",
+    "Retry" : "Reprovi",
+    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
+    "Sending …" : "Sendado...",
+    "Reply" : "Respondi",
     "Message" : "Mesaĝo",
-    "Delete" : "Forigi",
     "Copy to clipboard" : "Kopii tondejen",
     "Add" : "Aldoni",
-    "Search" : "Serĉi",
-    "Disabled" : "Malŝaltita",
-    "Enabled" : "Ŝaltita",
+    "Close" : "Malfermi",
+    "Date" : "Date",
+    "Tags" : "Etikedoj",
+    "Select tags" : "Elekti etikedojn",
+    "Last 7 days" : "Lastaj 7 tagoj",
+    "Clear" : "Viŝi",
     "Custom" : "Propra",
     "Signature …" : "Subskribo …",
     "Save signature" : "Konservi subskribon",
-    "Set" : "Uzi",
-    "Unset" : "Malprotekti",
+    "Delete tag" : "Forigi etikedon",
     "Tag already exists" : "La etikedo jam ekzistas",
     "Not found" : "Ne trovita",
-    "Remove" : "Forigi",
+    "Reply to sender only" : "Respondi nur al sendinto",
     "Untitled event" : "Sentitola okazaĵo",
     "Import into {calendar}" : "Importi en {calendar}",
     "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
@@ -134,26 +150,25 @@ OC.L10N.register(
     "Train" : "Trajno",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
+    "Actions" : "Agoj",
+    "Priority" : "Prioritato",
     "Mail app" : "Retpoŝtprogrameto",
     "Reset" : "Restarigi",
+    "Client ID" : "Klientidentigilo",
+    "Client secret" : "Klientosekreto",
     "Email: {email}" : "Retpoŝto: {email}",
-    "General" : "Ĝenerala",
     "IMAP" : "IMAP",
     "User" : "Uzanto",
     "Host" : "Gastigo",
     "Port" : "Pordo",
     "SMTP" : "SMTP",
-    "Keyboard shortcuts" : "Fulmoklavoj",
-    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
-    "Compose new message" : "Krei novan mesaĝon",
-    "Newer message" : "Pli nova mesaĝo",
-    "Older message" : "Pli malnova mesaĝo",
-    "Toggle star" : "Baskuligi stelon",
-    "Toggle unread" : "Baskuligi legostaton",
-    "Refresh" : "Aktualigi",
+    "E-mail address" : "Retpoŝtadreso",
+    "Valid until" : "Valida ĝis",
+    "Certificate" : "Atestilo",
+    "Submit" : "Sendi",
+    "Account connected" : "Konto konektita",
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
-    "Archive" : "Arĥivujo",
     "Drafts" : "Malnetujo",
     "Favorites" : "Pliŝataĵoj",
     "All inboxes" : "Ĉiuj ricevujoj",
@@ -174,6 +189,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
-    "Continue to %s" : "Daŭrigi al %s"
+    "Continue to %s" : "Daŭrigi al %s",
+    "Unselect" : "Malelekti"
 },
 "nplurals=2; plural=(n != 1);");
