@@ -23,74 +23,90 @@ OC.L10N.register(
     "Connecting" : "Conectando",
     "Save" : "Guardar",
     "Connect" : "Conectar",
-    "Change name" : "Cambiar nombre",
+    "Password required" : "Se requiere contraseña",
+    "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Go back" : "Regresar",
+    "Change name" : "Cambiar nombre",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
+    "General" : "General",
+    "Register" : "Registrar",
+    "Keyboard shortcuts" : "Atajos de teclado",
+    "Compose new message" : "Redactar nuevo mensaje",
+    "Newer message" : "Mensaje mas nuevo",
+    "Older message" : "Mensaje anterior",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Recargar",
     "Select account" : "Seleccione la cuenta",
     "Subject" : "Asunto",
     "Add attachment from Files" : "Agregar adjunto desde Archivos",
-    "Sending …" : "Enviando ...",
-    "Go back" : "Regresar",
-    "Retry" : "Reintentar",
-    "Message sent!" : "¡Mensaje enviado!",
-    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
+    "Choose" : "Elige",
+    "Confirm" : "Confirmar",
     "Favorite" : "Favorito",
     "Read" : "Leer",
-    "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
-    "Move" : "Mover",
-    "Forward" : "Reenviar",
+    "Back" : "Atrás",
     "All day" : "Todo el día",
+    "Description" : "Descripción",
     "Create" : "Crear",
+    "Select" : "Seleccionar",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
-    "Choose" : "Elige",
+    "More options" : "Más opciones",
+    "Remove" : "Borrar",
+    "email" : "correo electrónico",
     "Other" : "Otro",
-    "Reply" : "Responder",
+    "Forward" : "Reenviar",
+    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
     "Unnamed" : "Sin nombre",
-    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todos a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
+    "Move" : "Mover",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
-    "Edit name" : "Editar nombre",
+    "Rename" : "Renombrar",
     "Clear cache" : "Limpiar caché",
     "New message" : "Mensaje nuevo",
+    "Retry" : "Reintentar",
+    "Sending …" : "Enviando ...",
+    "Reply" : "Responder",
     "Message" : "Mensaje",
-    "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Añadir",
+    "Close" : "Cerrar",
+    "Date" : "Fecha",
     "Tags" : "Etiquetas",
-    "Search" : "Buscar",
-    "Disabled" : "Deshabilitado",
-    "Enabled" : "Habilitado",
+    "Clear" : "Borrar",
     "Custom" : "Personalizado",
-    "Unset" : "Desconectado",
+    "Add tag" : "Añadir etiqueta",
     "Tag already exists" : "La etiqueta ya existe",
-    "Remove" : "Borrar",
+    "Not found" : "No encontrado",
+    "Operator" : "Operador",
+    "Actions" : "Acciones",
+    "Priority" : "Prioridad",
     "Reset" : "Restablecer",
-    "General" : "General",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos de teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
-    "Compose new message" : "Redactar nuevo mensaje",
-    "Newer message" : "Mensaje mas nuevo",
-    "Older message" : "Mensaje anterior",
-    "Refresh" : "Recargar",
+    "Valid until" : "Válido hasta",
+    "Certificate" : "Certificado",
+    "Submit" : "Enviar",
+    "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecte su cuenta de correo",
     "All" : "Todos",
-    "Archive" : "Archivar",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
