@@ -3,14 +3,16 @@ OC.L10N.register(
     {
     "Embedded message %s" : "הודעה מוטמעת %s",
     "Important mail" : "דוא״ל חשוב",
+    "No message found yet" : "לא נמצאו הודעות עדיין",
+    "Set up an account" : "הגדרת חשבון",
     "Unread mail" : "דוא״ל שלא נקרא",
     "Important" : "חשוב",
     "Work" : "עבודה",
     "Personal" : "אישי",
     "To Do" : "מטלות",
     "Later" : "אחר כך",
-    "Mails" : "פריטי דוא״ל",
     "Mail" : "דואר",
+    "Mails" : "פריטי דוא״ל",
     "💌 A mail app for Nextcloud" : "💌 יישומון דוא״ל ל־Nextcloud",
     "Drafts are saved in:" : "הטיוטות נשמרות תחת:",
     "Sent messages are saved in:" : "ההודעות שנשלחות נשמרות תחת:",
@@ -38,30 +40,45 @@ OC.L10N.register(
     "Connecting" : "מתבצע חיבור",
     "Save" : "שמור",
     "Connect" : "התחברות",
+    "Password required" : "נדרשת ססמה",
     "Account settings" : "הגדרות חשבון",
-    "Change name" : "החלפת שם",
+    "Aliases" : "כינויים",
     "Signature" : "חתימה",
     "A signature is added to the text of new messages and replies." : "נוספה חתימה לטקסט של הודעות חדשות ותגובות.",
     "Writing mode" : "מצב כתיבה",
     "Preferred writing mode for new messages and replies." : "מצב כתיבה מועדף להודעות חדשות ולתגובות.",
     "Default folders" : "תיקיות בררת מחדל",
-    "Trusted senders" : "שולחים מהימנים",
     "Mail server" : "שרת דוא״ל",
+    "Go back" : "חזרה",
+    "Change name" : "החלפת שם",
     "Email address" : "כתובת דוא״ל",
     "Add alias" : "הוספת כינוי",
     "Cancel" : "ביטול",
     "Add mail account" : "הוספת חשבון דוא״ל",
+    "General" : "כללי",
+    "Sorting" : "מיון",
     "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
     "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
+    "Register" : "רישום",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
+    "Trusted senders" : "שולחים מהימנים",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Compose new message" : "כתיבת הודעה חדשה",
+    "Newer message" : "הודעה חדשה יותר",
+    "Older message" : "הודעה ישנה יותר",
+    "Toggle star" : "החלפת מצב כוכב",
+    "Toggle unread" : "החלפת מצב קריאה",
+    "Archive" : "לארכיון",
+    "Delete" : "מחיקה",
+    "Search" : "חיפוש",
+    "Send" : "שליחה",
+    "Refresh" : "רענון",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
     "To" : "אל",
     "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
     "Cc" : "עותק",
     "Bcc" : "עותק נסתר",
-    "No contacts found." : "לא נמצאו אנשי קשר.",
     "Subject" : "נושא",
     "Subject …" : "נושא…",
     "This message came from a noreply address so your reply will probably not be read." : "הודעה זו הגיעה מכתובת שאינה מיועדת למענה (noreply) ולכן כנראה שהתגובה שלך לא תיקרא.",
@@ -69,78 +86,71 @@ OC.L10N.register(
     "Write message …" : "כתיבת הודעה…",
     "Saving draft …" : "הטיוטה נשמרת…",
     "Draft saved" : "הטיוטה נשמרה",
+    "Enable formatting" : "הפעלת עיצוב",
     "Upload attachment" : "העלאת קובץ מצורף",
     "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
-    "Enable formatting" : "הפעלת עיצוב",
     "Request a read receipt" : "בקשת אישור קריאה",
     "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
     "Enter a date" : "נא למלא תאריך",
-    "Uploading attachments …" : "הקבצים המצורפים מועלים…",
-    "Sending …" : "שולח...",
-    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
-    "Go back" : "חזרה",
-    "Retry" : "ניסיון חוזר",
-    "Message sent!" : "הודעה נשלחה!",
-    "Add share link from {productName} Files" : "הוספת קישור שיתוף מקבצים של {productName}",
-    "Send" : "שליחה",
-    "Encrypt and send" : "להצפין ולשלוח",
-    "Send unencrypted" : "לשלוח ללא הצפנה",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
     "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
-    "No message found yet" : "לא נמצאו הודעות עדיין",
-    "Set up an account" : "הגדרת חשבון",
+    "Choose" : "בחר",
+    "Confirm" : "אימות",
     "Plain text" : "טקסט פשוט",
     "Rich text" : "טקסט עשיר",
     "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
+    "No messages" : "אין הודעות",
     "Draft: " : "טיוטה:",
     "Unfavorite" : "ביטול כמועדף",
     "Favorite" : "סימון כמועדף",
     "Read" : "קריאה",
     "Mark not spam" : "לסמן שזה לא ספאם",
     "Mark as spam" : "לסמן כספאם",
-    "Unselect" : "ביטול בחירה",
-    "Select" : "בחירה",
     "Edit tags" : "עריכת תגיות",
-    "Move" : "העברה",
     "Move thread" : "העברת שרשור",
     "Delete thread" : "מחיקת שרשור",
     "More actions" : "פעולות נוספות",
+    "Back" : "חזרה",
     "Edit as new message" : "עריכה כהודעה חדשה",
     "Create event" : "יצירת אירוע",
     "Blind copy recipients only" : "נמענים נסתרים בלבד",
     "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
     "Could not delete message" : "לא ניתן למחוק הודעה",
-    "Forward" : "העברה",
     "Load more" : "לטעון עוד",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
     "Report this bug" : "דיווח על התקלה הזו",
     "All day" : "כל היום",
+    "Description" : "תיאור",
     "Create" : "יצירה",
     "Could not create event" : "לא ניתן ליצור אירוע",
+    "Select" : "בחירה",
     "Comment" : "הערה",
     "Accept" : "אשר",
     "Decline" : "דחייה",
+    "domain" : "שם תחום",
+    "Remove" : "הסרה",
+    "email" : "דוא״ל",
+    "individual" : "יחיד",
+    "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
     "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
-    "Choose" : "בחר",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
-    "Reply" : "תגובה",
-    "Reply to sender only" : "להגיב לשולח בלבד",
+    "Forward" : "העברה",
     "View source" : "הצגת המקור",
-    "Message source" : "מקור ההודעה",
+    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
     "Import into calendar" : "ייבוא ליומן",
     "Download attachment" : "הורדת קובץ מצורף",
     "Save to Files" : "שמירה לקבצים",
     "Unnamed" : "ללא שם",
     "Embedded message" : "הודעה מוטמעת",
-    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
-    "Save all to Files" : "שמירת הכו לקבצים",
     "Choose a folder to store the attachments in" : "נא לבחור תיקייה לאחסן בה את הקבצים המצורפים",
+    "Save all to Files" : "שמירת הכו לקבצים",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "הודעה זו מוצפנת עם PGP. יש להתקין את Mailvelope כדי לפענח אותה.",
     "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
     "Message frame" : "מסגרת הודעה",
+    "Move" : "העברה",
     "Quota" : "מכיסה",
     "Add mailbox" : "הוספת תיבת דוא״ל",
     "Saving" : "שמירה",
@@ -148,14 +158,13 @@ OC.L10N.register(
     "Remove account" : "הסרת חשבון",
     "Loading …" : "בטעינה",
     "Not supported by the server" : "לא נתמך על ידי השרת",
-    "Remove account {email}" : "להסיר את החשבון {email}",
     "Remove {email}" : "להסיר את {email}",
     "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
     "Collapse mailboxes" : "צמצום תיבות דוא״ל",
     "Mark all as read" : "סימון הכול כנקרא",
     "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
     "Add submailbox" : "הוספת תת־תיבת דוא״ל",
-    "Edit name" : "ערוך שם",
+    "Rename" : "שינוי שם",
     "Clear cache" : "פינוי מטמון",
     "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
     "Sync in background" : "סנכרון ברקע",
@@ -163,41 +172,38 @@ OC.L10N.register(
     "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
     "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
-    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות","{total} הודעות"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
+    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "New message" : "הודעה חדשה",
-    "No message selected" : "לא נבחרה הודעה",
+    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
+    "Retry" : "ניסיון חוזר",
+    "Uploading attachments …" : "הקבצים המצורפים מועלים…",
+    "Sending …" : "שולח...",
+    "Reply" : "תגובה",
     "Message" : "הודעה",
     "Oh Snap!" : "שוד ושבר!",
-    "Delete" : "מחיקה",
     "Copy to clipboard" : "העתקה ללוח הגזירים",
     "Add" : "הוספה",
+    "Close" : "סגירה",
+    "Body" : "גוף",
+    "Date" : "תאריך",
     "Tags" : "תגיות",
     "Select tags" : "בחירת תגיות",
     "Clear" : "פינוי",
-    "Search" : "חיפוש",
-    "Date" : "תאריך",
-    "Disabled" : "מושבת",
-    "Enabled" : "מופעל",
-    "IMAP Credentials" : "פרטי גישה ל־IMAP",
     "Custom" : "מותאם אישית",
     "Signature …" : "חתימה…",
     "Save signature" : "שמירת החתימה",
-    "Set" : "הגדרה",
-    "Unset" : "ביטול הגדרה",
     "Add tag" : "הוספת תגית",
     "Saving tag …" : "התגית נשמרת…",
     "Tag already exists" : "תגית כבר קיימת",
     "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
+    "Not found" : "לא נמצא",
     "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
+    "Reply to sender only" : "להגיב לשולח בלבד",
     "Mark as unread" : "סימון כלא נקרא",
     "Mark as read" : "סימון כנקרא",
-    "Not found" : "לא נמצא",
-    "Remove" : "הסרה",
+    "Message source" : "מקור ההודעה",
     "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
     "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
-    "individual" : "יחיד",
-    "domain" : "שם תחום",
     "(organizer)" : "(מארגן)",
     "Untitled event" : "אירוע ללא כותרת",
     "Import into {calendar}" : "ייבוא לתוך {calendar}",
@@ -208,13 +214,16 @@ OC.L10N.register(
     "Train" : "רכבת",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
     "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
+    "Actions" : "פעולות",
+    "Priority" : "עדיפות",
     "Mail app" : "יישומון דוא״ל",
     "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
     "Reset" : "איפוס",
+    "Client ID" : "מזהה לקו",
+    "Client secret" : "סוד לקוח",
     "Email: {email}" : "דוא״ל: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
-    "General" : "כללי",
     "Email address template" : "תבנית כתובת דוא״ל",
     "IMAP" : "IMAP",
     "User" : "משתמש",
@@ -223,19 +232,13 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Save Config" : "שמירת הגדרות",
     "With the settings above, the app will create account settings in the following way:" : "עם ההגדרות שלהלן, היישומון יצור הגדרות חשבון באופן הבא:",
-    "Keyboard shortcut" : "קיצור מקלדת",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
-    "Compose new message" : "כתיבת הודעה חדשה",
-    "Newer message" : "הודעה חדשה יותר",
-    "Older message" : "הודעה ישנה יותר",
-    "Toggle star" : "החלפת מצב כוכב",
-    "Toggle unread" : "החלפת מצב קריאה",
-    "Refresh" : "רענון",
+    "E-mail address" : "כתובת דוא״ל",
+    "Valid until" : "בתוקף עד",
+    "Certificate" : "אישור",
+    "Submit" : "שליחה",
+    "Account connected" : "חשבון מחובר",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
-    "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
     "All" : "הכול",
-    "Archive" : "לארכיון",
     "Drafts" : "טיוטות",
     "Favorites" : "מועדפים",
     "Priority inbox" : "תיבת דואר נכנס בעדיפות",
@@ -246,7 +249,7 @@ OC.L10N.register(
     "Trash" : "פח אשפה",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
     "Nextcloud Mail" : "דוא״ל Nextcloud",
     "Attachments were not copied. Please add them manually." : "הקבצים המצורפים לא הועתקו. נא להוסיף אותם ידנית.",
     "Message sent" : "הודעה נשלחה",
@@ -260,6 +263,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s"
+    "Continue to %s" : "ממשיך אל %s",
+    "Unselect" : "ביטול בחירה"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
