@@ -3,14 +3,16 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ugrađena poruka %s",
     "Important mail" : "Važna pošta",
+    "No message found yet" : "Nije pronađena nijedna poruka",
+    "Set up an account" : "Postavi račun",
     "Unread mail" : "Nepročitana pošta",
     "Important" : "Važno",
     "Work" : "Posao",
     "Personal" : "Osobno",
     "To Do" : "Zadatak",
     "Later" : "Kasnije",
-    "Mails" : "Pošta",
     "Mail" : "Pošta",
+    "Mails" : "Pošta",
     "💌 A mail app for Nextcloud" : "💌 Aplikacija za upravljanje e-poštom za Nextcloud",
     "Drafts are saved in:" : "Skice se spremaju u:",
     "Sent messages are saved in:" : "Poslane poruke spremaju se u:",
@@ -38,31 +40,46 @@ OC.L10N.register(
     "Connecting" : "Povezivanje",
     "Save" : "Spremi",
     "Connect" : "Poveži",
+    "Password required" : "Potrebna zaporka",
     "Account settings" : "Postavke računa",
-    "Change name" : "Promijeni ime",
+    "Aliases" : "Pseudonimi",
     "Signature" : "Potpis",
     "A signature is added to the text of new messages and replies." : "Tekstu novih poruka i odgovora dodaje se potpis.",
     "Writing mode" : "Način pisanja",
     "Preferred writing mode for new messages and replies." : "Željeni način pisanja za nove poruke i odgovore.",
     "Default folders" : "Zadane mape",
-    "Sieve filter rules" : "Pravila filtra Sieve",
-    "Trusted senders" : "Pouzdani pošiljatelji",
     "Mail server" : "Poslužitelj e-pošte",
-    "Sieve filter server" : "Poslužitelj filtra Sieve",
     "Update alias" : "Ažuriraj pseudonim",
     "Show update alias form" : "Prikaži obrazac za ažuriranje pseudonima",
     "Delete alias" : "Izbriši pseudonim",
+    "Go back" : "Natrag",
+    "Change name" : "Promijeni ime",
     "Email address" : "Adresa e-pošte",
     "Add alias" : "Dodaj pseudonim",
     "Create alias" : "Stvori pseudonim",
     "Cancel" : "Odustani",
+    "Accounts" : "Korisnićki računi",
     "Add mail account" : "Dodaj račun e-pošte",
+    "General" : "Općenito",
+    "List" : "Popis",
+    "Sorting" : "Razvrstavanje",
     "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
     "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
-    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "Register" : "Registriraj se",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
+    "Trusted senders" : "Pouzdani pošiljatelji",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Compose new message" : "Sastavi novu poruku",
+    "Newer message" : "Novija poruka",
+    "Older message" : "Starija poruka",
+    "Toggle star" : "Uključi/isključi zvijezdu",
+    "Toggle unread" : "Uključi/isključi nepročitano",
+    "Archive" : "Arhiva",
+    "Delete" : "Izbriši",
+    "Search" : "Traži",
+    "Send" : "Pošalji",
+    "Refresh" : "Osvježi",
     "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
-    "Automatically classify importance of new email" : "Automatski klasificirajte važnost nove e-pošte",
     "Could not update preference" : "Ažuriranje postavki nije uspjelo",
     "From" : "Od",
     "Select account" : "Odaberi račun",
@@ -70,7 +87,6 @@ OC.L10N.register(
     "Contact or email address …" : "Kontakt ili adresa e-pošte...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Nikakvi kontakti nisu nađeni.",
     "Subject" : "Predmet",
     "Subject …" : "Naslov...",
     "This message came from a noreply address so your reply will probably not be read." : "Ova je poruka poslana s adrese na koju se ne može odgovoriti pa vaš odgovor vjerojatno nitko neće pročitati.",
@@ -78,57 +94,41 @@ OC.L10N.register(
     "Write message …" : "Napiši poruku...",
     "Saving draft …" : "Spremanje skice...",
     "Draft saved" : "Skica je spremljena",
+    "Enable formatting" : "Omogući oblikovanje",
     "Upload attachment" : "Otpremi privitak",
     "Add attachment from Files" : "Dodaj privitak iz datoteka",
-    "Enable formatting" : "Omogući oblikovanje",
     "Request a read receipt" : "Zatražite potvrdu o čitanju",
     "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
     "Enter a date" : "Unesi datum",
-    "Uploading attachments …" : "Otpremanje privitaka...",
-    "Sending …" : "Slanje…",
-    "Error sending your message" : "Pogreška pri slanju poruke",
-    "Go back" : "Natrag",
-    "Retry" : "Pokušaj ponovno",
-    "Warning sending your message" : "Upozorenje pri slanju poruke",
-    "Send anyway" : "Svejedno pošalji",
-    "Message sent!" : "Poruka poslana!",
-    "Add share link from {productName} Files" : "Dodaj poveznicu za dijeljenje iz datoteka {productName}",
-    "Send" : "Pošalji",
-    "Encrypt and send" : "Šifriraj i pošalji",
-    "Send unencrypted" : "Pošalji nešifrirano",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
-    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Privitak prekoračuje dopuštenu veličinu privitaka od {size}. Dijelite datoteku putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice."],
-    "No message found yet" : "Nije pronađena nijedna poruka",
-    "Set up an account" : "Postavi račun",
+    "Choose" : "Odaberite",
+    "Confirm" : "Potvrdi",
     "Plain text" : "Običan tekst",
     "Rich text" : "Bogat tekst",
     "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
+    "No messages" : "Nema poruka",
     "Draft: " : "Skica: ",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
     "Read" : "Čitaj",
     "Mark not spam" : "Označi da nije neželjena pošta",
     "Mark as spam" : "Označi kao neželjenu poštu",
-    "Unselect" : "Poništi odabir",
-    "Select" : "Odaberi",
     "Edit tags" : "Uredi oznake",
-    "Move" : "Premjesti",
     "Move thread" : "Premjesti dretvu",
     "Delete thread" : "Izbriši dretvu",
     "More actions" : "Dodatne radnje",
+    "Back" : "Natrag",
     "Edit as new message" : "Uredi kao novu poruku",
     "Create event" : "Stvori događaj",
+    "Create task" : "Stvori zadatak",
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
     "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Could not delete message" : "Brisanje poruke nije uspjelo",
-    "Forward" : "Naprijed",
     "Load more" : "Učitaj više",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} kao nepročitano","Označi {number} kao nepročitano","Označi {number} kao nepročitano"],
     "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} kao pročitano","Označi {number} kao pročitano","Označi {number} kao pročitano"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} kao nepročitano","Označi {number} kao nepročitano","Označi {number} kao nepročitano"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Označi {number} kao važan","Označi {number} kao važan","Označi {number} kao važan"],
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označi {number} kao nevažan","Označi {number} kao nevažan","Označi {number} kao nevažan"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Ukloni {number} iz favorita","Ukloni {number} iz favorita","Ukloni {number} iz favorita"],
@@ -136,21 +136,26 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Poništi odabir {number}","Poništi odabir {number}","Poništi odabir {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Premjesti {number} dretvu","Premjesti {number} dretve","Premjesti {number} dretvi"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Proslijedi {number} kao privitak","Proslijedi {number} kao privitak","Proslijedi {number} kao privitak"],
-    "_Delete {number} thread_::_Delete {number} threads_" : ["Izbriši {number} dretvu","Izbriši {number} dretve","Izbriši {number} dretvi"],
     "Report this bug" : "Prijavi ovu pogrešku",
     "All day" : "Cijeli dan",
+    "Description" : "Opis",
     "Create" : "Stvori",
     "Event created" : "Događaj je stvoren",
     "Could not create event" : "Nije moguće stvoriti događaj",
+    "Select" : "Odaberi",
     "Comment" : "Komentar",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
     "More options" : "Više mogućnosti",
+    "domain" : "domena",
+    "Remove" : "Ukloni",
+    "email" : "e-pošta",
+    "individual" : "pojedinac",
+    "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
     "Could not open mailbox" : "Nije moguće otvoriti sandučić",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
     "Choose target mailbox" : "Odaberi ciljni sandučić",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
-    "Choose" : "Odaberite",
     "Important info" : "Važne informacije",
     "Other" : "Ostalo",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
@@ -158,22 +163,20 @@ OC.L10N.register(
     "Notify the sender" : "Obavijestite pošiljatelja",
     "You sent a read confirmation to the sender of this message." : "Poslali ste potvrdu o čitanju pošiljatelju ove poruke.",
     "Could not send mdn" : "Nije moguće poslati mdn",
-    "Reply" : "Odgovori",
-    "Reply to sender only" : "Odgovori pošiljatelju",
+    "Forward" : "Naprijed",
     "Move message" : "Premjesti poruku",
     "View source" : "Vidi izvor",
     "Download thread data for debugging" : "Preuzmi podatke o dretvi radi otklanjanje pogrešaka",
-    "Message source" : "Izvor poruke",
     "Message body" : "Tijelo poruke",
+    "Choose a folder to store the attachment in" : "Izaberi mapu za spremanje privitka",
     "Import into calendar" : "Dodaj u kalendar",
     "Download attachment" : "Preuzmi privitak",
     "Save to Files" : "Spremi u datoteke",
     "Unnamed" : "Neimenovano",
     "Embedded message" : "Ugrađena poruka",
-    "Choose a folder to store the attachment in" : "Izaberi mapu za spremanje privitka",
+    "Choose a folder to store the attachments in" : "Izaberi mapu za spremanje privitaka",
     "Save all to Files" : "Spremi sve u datoteke",
     "Download Zip" : "Preuzmi Zip",
-    "Choose a folder to store the attachments in" : "Izaberi mapu za spremanje privitaka",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Ova je poruka šifrirana PGP-om. Instalirajte Mailvelope kako biste je dešifrirali.",
     "The images have been blocked to protect your privacy." : "Slike su blokirane u svrhu zaštite privatnosti.",
     "Show images" : "Prikaži slike",
@@ -182,6 +185,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Uvijek prikaži slike s {domain}",
     "Message frame" : "Okvir poruke",
     "Quoted text" : "Citirani tekst",
+    "Move" : "Premjesti",
     "Moving" : "Premještanje",
     "Moving thread" : "Premještanje dretve",
     "Moving message" : "Premještanje poruke",
@@ -196,7 +200,6 @@ OC.L10N.register(
     "Not supported by the server" : "Ne podržava poslužitelj",
     "{usage} of {limit} used" : "{usage} od {limit} iskorišteno",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} i podaci e-pošte spremljeni u predmemoriji uklonit će se iz Nextclouda, ali ne iz vašeg davatelja usluga e-pošte.",
-    "Remove account {email}" : "Ukloni račun {email}",
     "Remove {email}" : "Ukloni {email}",
     "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
     "Show all mailboxes" : "Prikaži sve sandučiće",
@@ -204,7 +207,7 @@ OC.L10N.register(
     "Mark all as read" : "Označi sve kao pročitano",
     "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
     "Add submailbox" : "Dodaj podsandučić",
-    "Edit name" : "Uredi naziv",
+    "Rename" : "Preimenuj",
     "Clear cache" : "Izbriši predmemoriju",
     "Clear locally cached data, in case there are issues with synchronization." : "Izbrišite podatke iz lokalnog međuspremnika u slučaju da postoje problemi sa sinkronizacijom.",
     "Subscribed" : "Pretplaćen",
@@ -214,30 +217,31 @@ OC.L10N.register(
     "Delete mailbox {name}" : "Izbriši sandučić {name}",
     "An error occurred, unable to rename the mailbox." : "Došlo je do pogreške, nije moguće promijeniti naziv sandučića.",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
     "New message" : "Nova poruka",
-    "No message selected" : "Nije odabrana nijedna poruka",
+    "Error sending your message" : "Pogreška pri slanju poruke",
+    "Retry" : "Pokušaj ponovno",
+    "Uploading attachments …" : "Otpremanje privitaka...",
+    "Sending …" : "Slanje…",
+    "Warning sending your message" : "Upozorenje pri slanju poruke",
+    "Send anyway" : "Svejedno pošalji",
+    "Reply" : "Odgovori",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Message" : "Poruka",
     "Oh Snap!" : "Oh Snap!",
-    "Delete" : "Izbriši",
     "Contacts with this address" : "Kontakti s ovom adresom",
     "Add to Contact" : "Dodaj kontaktu",
     "New Contact" : "Novi kontakt",
     "Copy to clipboard" : "Kopiraj u međuspremnik",
     "Contact name …" : "Naziv kontakta…",
     "Add" : "Dodaj",
+    "Close" : "Zatvori",
+    "Body" : "Tijelo",
+    "Date" : "Datum",
     "Tags" : "Oznake",
     "Select tags" : "Odaberite oznake",
     "Clear" : "Izbriši",
-    "Search" : "Traži",
-    "Date" : "Datum",
-    "Disabled" : "Onemogućeno",
-    "Enabled" : "Omogućeno",
-    "Sieve Host" : "Sieve poslužitelj",
-    "Sieve Security" : "Sieve sigurnost",
     "Sieve Port" : "Sieve port",
-    "Sieve Credentials" : "Vjerodajnice za Sieve",
-    "IMAP Credentials" : "Vjerodajnice za IMAP",
     "Custom" : "Prilagođeno",
     "Sieve User" : "Sieve korisnik",
     "Sieve Password" : "Sieve zaporka",
@@ -246,26 +250,24 @@ OC.L10N.register(
     "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
-    "Add default tags" : "Dodaj zadane oznake",
-    "Rename tag" : "Preimenuj oznaku",
     "Saving new tag name …" : "Spremanje novog naziva oznake…",
-    "Set" : "Postavi",
-    "Unset" : "Ukloni",
+    "Delete tag" : "Izbriši oznaku",
+    "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
+    "Add default tags" : "Dodaj zadane oznake",
     "Add tag" : "Dodaj oznaku",
     "Saving tag …" : "Spremanje oznake...",
     "Tag already exists" : "Oznaka već postoji",
     "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
-    "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
+    "Not found" : "Nije pronađeno",
     "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
+    "Unsubscribe" : "Otkaži pretplatu",
+    "Reply to sender only" : "Odgovori pošiljatelju",
     "Mark as unread" : "Označi kao nepročitano",
     "Mark as read" : "Označi kao pročitano",
     "Delete message" : "Izbriši poruku",
-    "Not found" : "Nije pronađeno",
-    "Remove" : "Ukloni",
+    "Message source" : "Izvor poruke",
     "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
-    "individual" : "pojedinac",
-    "domain" : "domena",
     "(organizer)" : "(organizator)",
     "Untitled event" : "Događaj bez naslova",
     "Import into {calendar}" : "Uvezi u {calendar}",
@@ -276,6 +278,8 @@ OC.L10N.register(
     "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
+    "Actions" : "Radnje",
+    "Priority" : "Prioritet",
     "Mail app" : "Aplikacija za upravljanje e-poštom",
     "The mail app allows users to read mails on their IMAP accounts." : "Aplikacija za upravljanje e-poštom omogućuje korisnicima da čitaju svoje poruke s IMAP računa.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Ovdje možete pronaći postavke za čitavu instancu. Postavke za pojedinog korisnika nalaze se u samoj aplikaciji (donji lijevi kut).",
@@ -313,13 +317,14 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
     "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
     "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
+    "Client ID" : "ID klijenta",
+    "Client secret" : "Tajni ključ klijenta",
     "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
     "Email: {email}" : "E-pošta: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} šifriranje)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} šifriranje)",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} ({ssl} šifriranje)",
     "Configuration for \"{provisioningDomain}\"" : "Konfiguracija za „{provisioningDomain}“",
-    "General" : "Općenito",
     "Provisioning domain" : "Dodjeljivanje domene",
     "Email address template" : "Predložak adrese e-pošte",
     "IMAP" : "IMAP",
@@ -338,19 +343,13 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Ukini dodjelu i izbriši konfiguraciju",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% bit će zamijenjeni korisničkim UID-om i e-poštom",
     "With the settings above, the app will create account settings in the following way:" : "Aplikacija će primijeniti navedene postavke i stvoriti račun na sljedeći način:",
-    "Keyboard shortcut" : "Tipkovni prečac",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Speed up your Mail experience with these quick shortcuts." : "Ubrzajte korištenje e-pošte s pomoću ovih brzih prečaca.",
-    "Compose new message" : "Sastavi novu poruku",
-    "Newer message" : "Novija poruka",
-    "Older message" : "Starija poruka",
-    "Toggle star" : "Uključi/isključi zvijezdu",
-    "Toggle unread" : "Uključi/isključi nepročitano",
-    "Refresh" : "Osvježi",
+    "E-mail address" : "Adresa e-pošte",
+    "Valid until" : "Vrijedi do",
+    "Certificate" : "Vjerodajnica",
+    "Submit" : "Šalji",
+    "Account connected" : "Račun povezan",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
-    "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
     "All" : "Sve",
-    "Archive" : "Arhiva",
     "Drafts" : "Skice",
     "Favorites" : "Favoriti",
     "Priority inbox" : "Prioritetni sandučić",
@@ -375,6 +374,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s"
+    "Continue to %s" : "Idi do %s",
+    "Sieve filter rules" : "Pravila filtra Sieve",
+    "Sieve filter server" : "Poslužitelj filtra Sieve",
+    "Unselect" : "Poništi odabir"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
