@@ -5,7 +5,7 @@ OC.L10N.register(
     "Work" : "Kantor",
     "Personal" : "Pribadi",
     "Later" : "Nanti",
-    "Mail" : "Email",
+    "Mail" : "Surel",
     "Name" : "Nama",
     "Password" : "Kata kunci",
     "None" : "Tidak ada",
@@ -15,70 +15,85 @@ OC.L10N.register(
     "Connecting" : "Menyambungkan",
     "Save" : "Simpan",
     "Connect" : "Sambungkan",
+    "Password required" : "Kata sandi diperlukan",
     "Signature" : "Tanda",
-    "Email address" : "Alamat email",
+    "Go back" : "Kembali",
+    "Email address" : "Alamat surel",
     "Cancel" : "Membatalkan",
-    "Add mail account" : "Tambahkan akun email",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "Add mail account" : "Tambahkan akun surel",
+    "General" : "Umum",
+    "List" : "Daftar",
+    "Register" : "Daftar",
+    "Keyboard shortcuts" : "Pintasan keyboard",
+    "Archive" : "Arsip",
+    "Delete" : "Hapus",
+    "Search" : "Cari",
+    "Send" : "Kirim",
+    "Refresh" : "Segarkan",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
-    "Sending …" : "Mengirim ...",
-    "Go back" : "Kembali",
-    "Retry" : "Ulangi",
-    "Message sent!" : "Kirim pesan!",
-    "Send" : "Kirim",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
+    "Choose" : "Pilih",
+    "Confirm" : "Konfirmasi",
     "Favorite" : "Favorit",
     "Read" : "Baca",
-    "Unselect" : "Batal pilih",
-    "Select" : "Pilih",
     "Edit tags" : "Sunting label",
-    "Move" : "Pindah",
+    "Back" : "Kembali",
     "Create event" : "Buat acara",
-    "Forward" : "Teruskan",
     "All day" : "Sepanjang hari",
+    "Description" : "Deskrisi",
     "Create" : "Buat",
+    "Select" : "Pilih",
     "Comment" : "Komentar",
     "Accept" : "Terima",
     "Decline" : "Tolak",
-    "Choose" : "Pilih",
+    "Remove" : "Buang",
+    "email" : "surel",
     "Other" : "Lainnya",
-    "Reply" : "Balas",
+    "Forward" : "Teruskan",
+    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
     "Import into calendar" : "Impor ke kalender",
     "Download attachment" : "Unduh lampiran",
-    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
+    "Move" : "Pindah",
     "Quota" : "Kuota",
     "Saving" : "Menyimpan",
     "Remove account" : "Hapus akun",
     "Mark all as read" : "Tandai semua telah dibaca",
-    "Edit name" : "Edit nama",
+    "Rename" : "Ubah nama",
     "Clear cache" : "Bersihkan cache",
     "New message" : "Pesan baru",
+    "Retry" : "Ulangi",
+    "Sending …" : "Mengirim ...",
+    "Draft" : "Draf",
+    "Reply" : "Balas",
     "Message" : "Pesan",
-    "Delete" : "Hapus",
+    "Copy to clipboard" : "Salin ke papan klip",
     "Add" : "Masukkan",
+    "Close" : "Tutup",
+    "Date" : "Date",
     "Tags" : "Tag",
     "Clear" : "Bersihkan",
-    "Search" : "Cari",
-    "Date" : "Date",
-    "Disabled" : "Dinonaktifkan",
-    "Enabled" : "Diaktifkan",
+    "Add tag" : "Tambahkan tag",
     "Tag already exists" : "Tag sudah ada",
+    "Unsubscribe" : "Berhenti berlangganan",
+    "Mark as unread" : "Tandai belum dibaca",
     "Mark as read" : "tandai sudah dibaca",
-    "Remove" : "Buang",
     "(organizer)" : "(penyelenggara)",
     "Untitled event" : "Acara tanpa judul",
+    "Operator" : "Operator",
+    "Actions" : "Tindakan",
+    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
     "Reset" : "Setel ulang",
-    "General" : "Umum",
+    "Client ID" : "ID Klien",
+    "Client secret" : "Rahasia klien",
     "User" : "Pengguna",
     "Host" : "Host",
     "Port" : "Port",
-    "Keyboard shortcut" : "Pintasan keyboard",
-    "Keyboard shortcuts" : "Pintasan keyboard",
-    "Refresh" : "Segarkan",
-    "Connect your mail account" : "Hubungkan akun email Anda",
+    "Valid until" : "Berlaku sampai",
+    "Certificate" : "Sertifikat",
+    "Account connected" : "Akun terhubung",
+    "Connect your mail account" : "Hubungkan akun surel Anda",
     "All" : "Semua",
-    "Archive" : "Arsip",
     "Drafts" : "Konsep",
     "Favorites" : "Disukai",
     "All inboxes" : "Semua kotak masuk",
@@ -90,6 +105,7 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s"
+    "Continue to %s" : "Lanjutkan ke %s",
+    "Unselect" : "Batal pilih"
 },
 "nplurals=1; plural=0;");
