@@ -23,78 +23,94 @@ OC.L10N.register(
     "Connecting" : "მყარდება კავშირი",
     "Save" : "შენახვა",
     "Connect" : "დაკავშირება",
+    "Password required" : "საჭიროა პაროლი",
+    "Aliases" : "სხვანაირი სახელი",
     "Signature" : "ხელმოწერა",
-    "Cancel" : "უარყოფა",
-    "Add mail account" : "საფოსტო ანგარიშის დამატება",
-    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
-    "Select account" : "აირჩიეთ ანგარიში",
-    "Subject" : "სათაური",
-    "Upload attachment" : "დანართის ატვირთვა",
-    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
-    "Sending …" : "იგზავნება …",
     "Go back" : "უკან დაბრუნება",
-    "Retry" : "ვცადოთ ახლიდან",
-    "Message sent!" : "წერილი გაგზავნილია!",
-    "Send" : "გაგზავნა",
-    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
-    "Unfavorite" : "რჩეულებიდან ამოშლა",
-    "Favorite" : "რჩეული",
-    "Read" : "წაკითხვა",
-    "Select" : "არჩევა",
-    "Edit tags" : "შეცვალეთ ტეგები",
-    "Move" : "გადატანა",
-    "More actions" : "მეტი ქმედება",
-    "Forward" : "წინ",
-    "All day" : "მთელი დღე",
-    "Create" : "შექმნა",
-    "Comment" : "კომენტარი",
-    "Accept" : "მიღება",
-    "Decline" : "ურაყოფა",
-    "Choose" : "აირჩიეთ",
-    "Other" : "სხვა",
-    "Reply" : "პასუხი",
-    "Import into calendar" : "იმპორტი კალენდარში",
-    "Download attachment" : "დანართის გადმოწერა",
-    "Save to Files" : "შენახვა ფაილებში",
-    "Unnamed" : "უსახელო",
-    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
-    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
-    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
-    "Quota" : "კვოტა",
-    "Saving" : "მიმდინარეობს შენახვა",
-    "Remove account" : "ანგარიშის გაუქმება",
-    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
-    "Clear cache" : "კეშის გასუფთავება",
-    "New message" : "ახალი წერილი",
-    "Message" : "წერილი",
-    "Delete" : "გაუქმება",
-    "Copy to clipboard" : "კოპირება ბუფერში",
-    "Add" : "დამატება",
-    "Disabled" : "არაა მოქმედი",
-    "Enabled" : "მოქმედია",
-    "Custom" : "ინდივიდუალური",
-    "Add tag" : "ტეგის დამატება",
-    "Mark as unread" : "წაუკითხავად მონიშვნა",
-    "Mark as read" : "წაკითხულად მონიშვნა",
-    "Remove" : "წაშლა",
-    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
+    "Cancel" : "უარყოფა",
+    "Accounts" : "ანგარიში",
+    "Add mail account" : "საფოსტო ანგარიშის დამატება",
     "General" : "ზოგადი",
-    "User" : "მომხმარებელი",
-    "Host" : "ჰოსტი",
-    "Port" : "პორტი",
-    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
+    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
+    "Register" : "რეგისტრაცია",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
-    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
     "Older message" : "ძველი წერილი",
     "Toggle star" : "ვარსკლავის გადართვა",
     "Toggle unread" : "წაუკითხავის გადართვა",
+    "Archive" : "არქივი",
+    "Delete" : "გაუქმება",
     "Search" : "ძიება",
+    "Send" : "გაგზავნა",
     "Refresh" : "განახლება",
+    "Select account" : "აირჩიეთ ანგარიში",
+    "Subject" : "სათაური",
+    "Upload attachment" : "დანართის ატვირთვა",
+    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
+    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
+    "Choose" : "აირჩიეთ",
+    "Confirm" : "დადასტურება",
+    "Unfavorite" : "რჩეულებიდან ამოშლა",
+    "Favorite" : "რჩეული",
+    "Read" : "წაკითხვა",
+    "Edit tags" : "შეცვალეთ ტეგები",
+    "More actions" : "მეტი ქმედება",
+    "Back" : "უკან",
+    "All day" : "მთელი დღე",
+    "Description" : "აღწერილობა",
+    "Create" : "შექმნა",
+    "Select" : "არჩევა",
+    "Comment" : "კომენტარი",
+    "Accept" : "მიღება",
+    "Decline" : "ურაყოფა",
+    "Remove" : "წაშლა",
+    "email" : "ელ-ფოსტა",
+    "Other" : "სხვა",
+    "Forward" : "წინ",
+    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
+    "Import into calendar" : "იმპორტი კალენდარში",
+    "Download attachment" : "დანართის გადმოწერა",
+    "Save to Files" : "შენახვა ფაილებში",
+    "Unnamed" : "უსახელო",
+    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
+    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
+    "Move" : "გადატანა",
+    "Quota" : "კვოტა",
+    "Saving" : "მიმდინარეობს შენახვა",
+    "Remove account" : "ანგარიშის გაუქმება",
+    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
+    "Rename" : "სახელის შეცვლა",
+    "Clear cache" : "კეშის გასუფთავება",
+    "New message" : "ახალი წერილი",
+    "Retry" : "ვცადოთ ახლიდან",
+    "Sending …" : "იგზავნება …",
+    "Reply" : "პასუხი",
+    "Message" : "წერილი",
+    "Copy to clipboard" : "კოპირება ბუფერში",
+    "Add" : "დამატება",
+    "Close" : "დახურვა",
+    "Date" : "თარიღი",
+    "Tags" : "ტეგები",
+    "Select tags" : "აირჩიეთ ტეგები",
+    "Clear" : "გასუფთავება",
+    "Custom" : "ინდივიდუალური",
+    "Add tag" : "ტეგის დამატება",
+    "Mark as unread" : "წაუკითხავად მონიშვნა",
+    "Mark as read" : "წაკითხულად მონიშვნა",
+    "Actions" : "მოქმედებები",
+    "Priority" : "პრიორიტეტი",
+    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
+    "Client ID" : "კლიენტის ID",
+    "Client secret" : "კლიენტის საიდუმლო",
+    "User" : "მომხმარებელი",
+    "Host" : "ჰოსტი",
+    "Port" : "პორტი",
+    "Valid until" : "ვარგისია",
+    "Certificate" : "სერტიფიკატი",
+    "Submit" : "გაგზავნა",
     "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
-    "Archive" : "არქივი",
     "Drafts" : "მონახაზები",
     "Favorites" : "რჩეულები",
     "All inboxes" : "ყველა ინბოქსი",
