@@ -11,25 +11,29 @@ OC.L10N.register(
     "Save" : "រក្សាទុក",
     "Connect" : "ភ្ជាប់",
     "Cancel" : "បោះបង់",
-    "Sending …" : "កំពុង​ផ្ញើរ...",
-    "Send" : "ផ្ញើ",
-    "Select" : "Select",
-    "Move" : "Move",
-    "Create" : "បង្កើត",
-    "Comment" : "មតិ",
-    "Choose" : "ជ្រើស",
-    "Other" : "ផ្សេងៗ",
-    "Reply" : "ឆ្លើយតប",
-    "Delete" : "លុប",
-    "Add" : "បញ្ចូល",
-    "Disabled" : "បាន​បិទ",
-    "Enabled" : "បាន​បើក",
-    "Remove" : "ដកចេញ",
     "General" : "ទូទៅ",
+    "Delete" : "លុប",
+    "Search" : "Search",
+    "Send" : "ផ្ញើ",
+    "Choose" : "ជ្រើស",
+    "Back" : "ត្រឡប់ក្រោយ",
+    "Description" : "ការ​អធិប្បាយ",
+    "Create" : "បង្កើត",
+    "Select" : "Select",
+    "Comment" : "មតិ",
+    "Remove" : "ដកចេញ",
+    "Other" : "ផ្សេងៗ",
+    "Move" : "Move",
+    "Rename" : "ប្ដូរ​ឈ្មោះ",
+    "Sending …" : "កំពុង​ផ្ញើរ...",
+    "Reply" : "ឆ្លើយតប",
+    "Add" : "បញ្ចូល",
+    "Close" : "បិទ",
+    "Date" : "កាលបរិច្ឆេទ",
+    "Tags" : "ស្លាក",
     "User" : "User",
     "Host" : "ម៉ាស៊ីន​ផ្ទុក",
     "Port" : "ច្រក",
-    "Search" : "Search",
     "All" : "ទាំងអស់",
     "Drafts" : "ពង្រាង",
     "Favorites" : "Favorites",
