@@ -10,36 +10,43 @@ OC.L10N.register(
     "None" : "Keng",
     "Save" : "Späicheren",
     "Connect" : "Verbannen",
-    "Cancel" : "Ofbriechen",
-    "Select account" : "Account auswielen",
     "Go back" : "Zeréckgoen",
+    "Cancel" : "Ofbriechen",
+    "General" : "Allgemeng",
+    "Delete" : "Läschen",
+    "Search" : "Search",
     "Send" : "Schécken",
-    "Favorite" : "Favorit",
-    "Select" : "Select",
-    "Edit tags" : "Tags editéieren",
-    "Move" : "Verschieben",
-    "Create" : "Erstellen",
-    "Comment" : "Kommentar",
+    "Refresh" : "Opfrëschen",
+    "Select account" : "Account auswielen",
     "Choose" : "Auswielen",
+    "Confirm" : "Konfirméieren",
+    "Favorite" : "Favorit",
+    "Edit tags" : "Tags editéieren",
+    "Back" : "Zeréck",
+    "Description" : "Beschreiwung",
+    "Create" : "Erstellen",
+    "Select" : "Select",
+    "Comment" : "Kommentar",
+    "Remove" : "Läschen",
     "Other" : "Aner",
-    "Reply" : "Äntwerten",
     "Unnamed" : "ouni Numm",
+    "Move" : "Verschieben",
     "Quota" : "Quota",
     "Saving" : "Speicheren...",
     "Remove account" : "De Kont läschen",
-    "Delete" : "Läschen",
+    "Rename" : "Ëmbenennen",
+    "Reply" : "Äntwerten",
     "Add" : "Derbäimaachen",
-    "Disabled" : "Deaktivéiert",
-    "Enabled" : "Aktivéiert",
+    "Close" : "Zoumaachen",
+    "Date" : "Date",
+    "Tags" : "Tags",
     "Custom" : "Individualiséier",
-    "Remove" : "Läschen",
+    "Actions" : "Aktiounen",
     "Reset" : "Zeréck setzen",
-    "General" : "Allgemeng",
+    "Client ID" : "Client ID",
     "User" : "User",
     "Host" : "Host",
     "Port" : "Port",
-    "Search" : "Search",
-    "Refresh" : "Opfrëschen",
     "All" : "All",
     "Favorites" : "Favoriten"
 },
