@@ -2,12 +2,13 @@ OC.L10N.register(
     "mail",
     {
     "Embedded message %s" : "Iegultais ziņojums%s",
+    "Important mail" : "Svarīgs pasts",
     "Important" : "Svarīgi",
     "Work" : "Darbs",
     "Personal" : "Personīgs",
     "Later" : "Vēlāk",
-    "Mails" : "E-pasta sūtījumi",
     "Mail" : "E-pasts",
+    "Mails" : "E-pasta sūtījumi",
     "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
     "Auto" : "Automātiski",
     "Name" : "Nosaukums",
@@ -32,87 +33,116 @@ OC.L10N.register(
     "Connecting" : "Savienojuma izveide",
     "Save" : "Saglabāt",
     "Connect" : "Savienoties",
+    "Password required" : "Nepieciešama parole",
+    "Account settings" : "Konta iestatījumi",
+    "Aliases" : "Aizstājvārdi",
     "Signature" : "Paraksts",
+    "Filters" : "Filtri",
+    "Go back" : "Atpakaļ",
+    "Email address" : "E-pasta adrese",
     "Cancel" : "Atcelt",
+    "Accounts" : "Konti",
     "Add mail account" : "Pievienot e-pasta kontu",
+    "General" : "Vispārīgs",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
+    "Archive" : "Arhīvi",
+    "Delete" : "Dzēst",
+    "Search" : "Meklēt",
+    "Send" : "Sūtīt",
+    "Refresh" : "Atsvaidzināt",
     "Select account" : "Izvēlieties kontu",
     "Subject" : "Temats",
     "Write message …" : "Rakstiet ziņu...",
-    "Add attachment from Files" : "Pievienot pielikumu no failiem",
+    "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
     "Enter a date" : "Ievadiet datumu",
-    "Sending …" : "Sūta …",
-    "Go back" : "Atpakaļ",
-    "Retry" : "Mēģināt vēlreiz",
-    "Message sent!" : "Vēstule aizsūtīta!",
-    "Send" : "Sūtīt",
     "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
-    "Favorite" : "Favorīts",
+    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
+    "Choose" : "Izvēlies",
+    "Confirm" : "Apstiprināt",
+    "Favorite" : "Izlasē",
     "Read" : "Lasīt",
-    "Unselect" : "Noņemt atlasi",
-    "Select" : "Atzīmēt",
-    "Edit tags" : "Rediģēt atzīmes",
-    "Move" : "Pārvietot",
-    "Forward" : "Turpināt",
+    "Edit tags" : "Labot birkas",
+    "Back" : "Atpakaļ",
+    "Create event" : "Izveidot notikumu",
+    "Load more" : "Ielādēt vairāk",
     "All day" : "Visas dienas",
+    "Description" : "Apraksts",
     "Create" : "Izveidot",
-    "Comment" : "Komentārs",
+    "Select" : "Atzīmēt",
+    "Comment" : "Piebilde",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
-    "Choose" : "Izvēlies",
+    "More options" : "Vairāk opciju",
+    "Remove" : "Noņemt",
+    "email" : "e-pasts",
     "Other" : "Cits",
-    "Reply" : "Atbildēt",
+    "Forward" : "Turpināt",
     "View source" : "Skatīt avotu",
+    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
     "Import into calendar" : "Importēt kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
     "Unnamed" : "Nenosaukts",
-    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
     "Save all to Files" : "Saglabāt visu uz Datnes",
-    "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
+    "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
+    "Show images" : "Parādīt attēlus",
+    "Show images temporarily" : "Īslaicīgi parādīt attēlus",
+    "Move" : "Pārvietot",
     "Quota" : "Kvota",
     "Saving" : "Saglabā",
     "Remove account" : "Noņemt kontu",
+    "Loading …" : "Ielādē…",
+    "Rename" : "Pārsaukt",
+    "Subscribed" : "Abonēts",
     "New message" : "Jauna ziņa",
+    "Retry" : "Mēģināt vēlreiz",
+    "Sending …" : "Sūta …",
+    "Reply" : "Atbildēt",
     "Message" : "Ziņojums",
-    "Delete" : "Dzēst",
     "Copy to clipboard" : "Kopēt starpliktuvē",
     "Add" : "Pievienot",
-    "Tags" : "Birkas",
-    "Select tags" : "Izvēlies birkas",
-    "Search" : "Meklēt",
+    "Search in mailbox" : "Meklēt pastkastē",
+    "Close" : "Aizvērt",
     "Date" : "Datums",
-    "Disabled" : "Atspējots",
-    "Enabled" : "Iespējots",
+    "Tags" : "Birkas",
+    "Select tags" : "Atlasīt birkas",
+    "Clear" : "Notīrīt",
     "Custom" : "Pielāgots",
-    "Unset" : "Neuzstādīts",
+    "Delete tag" : "Dzēst atzīmi",
     "Tag already exists" : "Birka jau pastāv",
-    "Remove" : "Noņemt",
+    "Not found" : "Nav atrasts",
+    "Untitled event" : "Nenosaukts notikums",
+    "Operator" : "Operators",
+    "Actions" : "Darbības",
+    "Priority" : "Prioritāte",
+    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
-    "General" : "Vispārīgs",
+    "Client ID" : "Klienta ID",
     "User" : "Lietotājs",
     "Host" : "Resursdators",
     "Port" : "Ports",
-    "Keyboard shortcut" : "Tastatūras saīsne",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
-    "Refresh" : "Atsvaidzināt",
-    "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
+    "Valid until" : "Derīgs līdz",
+    "Certificate" : "Sertifikāts",
+    "Submit" : "Iesniegt",
+    "Connect your mail account" : "Pievienot savu e-pasta kontu",
     "All" : "Visi",
-    "Archive" : "Arhīvi",
     "Drafts" : "Melnraksti",
-    "Favorites" : "Favorīti",
+    "Favorites" : "Izlases vienumi",
     "All inboxes" : "Visas iesūtnes",
     "Inbox" : "Iesūtne",
     "Junk" : "Nevēlams",
     "Sent" : "Izsūtne",
     "Trash" : "Miskaste",
+    "Error while sharing file" : "Kļūda datnes kopīgošanā",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
     "Error loading message" : "Kļūda ielādējot vēstuli",
     "Forwarding to %s" : "Pārsūtīt uz %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
+    "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Unselect" : "Noņemt atlasi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
