@@ -3,14 +3,16 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ingebed bericht %s",
     "Important mail" : "Belangrijke mail",
+    "No message found yet" : "Nog geen berichten gevonden",
+    "Set up an account" : "Maak een account aan",
     "Unread mail" : "Ongelezen mail",
     "Important" : "Belangrijk",
     "Work" : "Werk",
     "Personal" : "Persoonlijk",
     "To Do" : "Te doen",
     "Later" : "Later",
-    "Mails" : "Mails",
     "Mail" : "E-mail",
+    "Mails" : "Mails",
     "💌 A mail app for Nextcloud" : "💌 Een e-mail app voor Nextcloud",
     "Drafts are saved in:" : "Concepten worden opgeslagen in:",
     "Sent messages are saved in:" : "Verzonden berichten worden opgeslagen in:",
@@ -37,34 +39,51 @@ OC.L10N.register(
     "SMTP User" : "SMTP gebruikersnaam",
     "SMTP Password" : "SMTP wachtwoord",
     "Connecting" : "Verbinden",
+    "Sign in with Google" : "Inloggen met Google",
     "Save" : "Bewaren",
     "Connect" : "Verbinden",
+    "Password required" : "Wachtwoord vereist",
     "Account settings" : "Accountinstellingen",
-    "Change name" : "Naam veranderen",
+    "Aliases" : "Aliassen",
     "Signature" : "Handtekening",
     "A signature is added to the text of new messages and replies." : "Een handtekening wordt toegevoegd aan de tekst van nieuwe berichten en antwoorden.",
     "Writing mode" : "Schrijfmodus",
     "Preferred writing mode for new messages and replies." : "Gewenste schrijfmodus voor nieuwe berichten en antwoorden.",
     "Default folders" : "Standaardmappen",
-    "The folders to use for drafts, sent messages and deleted messages." : "De mappen voor concepten, verstuurde berichten en verwijderde berichten.",
-    "Sieve filter rules" : "Sieve filterregels",
-    "Trusted senders" : "Vertrouwde afzenders",
+    "Filters" : "Filters",
     "Mail server" : "Mailserver",
-    "Sieve filter server" : "Sieve filterserver",
     "Update alias" : "Bijwerken alias",
     "Show update alias form" : "Toon formulier Bijwerken alias",
     "Delete alias" : "Verwijderen alias",
+    "Go back" : "Ga terug",
+    "Change name" : "Naam veranderen",
     "Email address" : "E-mailadres",
     "Add alias" : "Voeg bijnaam toe",
     "Create alias" : "Aanmaken alias",
     "Cancel" : "Annuleren",
+    "Accounts" : "Accounts",
     "Add mail account" : "Voeg e-mailaccount toe",
+    "General" : "Algemeen",
+    "Layout" : "Layout",
+    "List" : "Lijst",
+    "Sorting" : "Sorteren",
     "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
     "Register as application for mail links" : "Registreer als applicatie voor e-maillinks",
-    "Show keyboard shortcuts" : "Toon sneltoetsen",
+    "Register" : "Aanmelden",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Laat de app gegevens verzamelen over jouw interacties. Op basis van deze gegevens zal de app zich aanpassen aan je voorkeuren. De gegevens worden alleen lokaal opgeslagen.",
+    "Trusted senders" : "Vertrouwde afzenders",
+    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
+    "Compose new message" : "Opstellen nieuw bericht",
+    "Newer message" : "Recenter bericht",
+    "Older message" : "Ouder bericht",
+    "Toggle star" : "Omschakelen ster",
+    "Toggle unread" : "Omschakelen ongelezen",
+    "Archive" : "Archiveer",
+    "Delete" : "Verwijderen",
+    "Search" : "Zoeken",
+    "Send" : "Versturen",
+    "Refresh" : "Verversen",
     "Put my text to the bottom of a reply instead of on top of it." : "Zet mijn tekst onderaan een antwoord in plaats van erboven.",
-    "Automatically classify importance of new email" : "Automatisch classificeren van belangrijke e-mails",
     "Could not update preference" : "Kon voorkeuren niet bijwerken",
     "From" : "Van",
     "Select account" : "Selecteer account",
@@ -72,7 +91,6 @@ OC.L10N.register(
     "Contact or email address …" : "Contact of e-mailadres ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Geen contacten gevonden.",
     "Subject" : "Onderwerp",
     "Subject …" : "Onderwerp ...",
     "This message came from a noreply address so your reply will probably not be read." : "Dit bericht kwam van een noreply-adres. Je antwoord zal dus niet worden gelezen.",
@@ -81,35 +99,22 @@ OC.L10N.register(
     "Saving draft …" : "Concept aan het opslaan ...",
     "Draft saved" : "Concept opgeslagen",
     "Discard & close draft" : "Verwijderen & concept sluiten",
+    "Enable formatting" : "Inschakelen formattering",
     "Upload attachment" : "Bijlage uploaden",
     "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
-    "Enable formatting" : "Inschakelen formattering",
     "Request a read receipt" : "Vraag een leesbevestiging",
     "Encrypt message with Mailvelope" : "Versleutel bericht met Mailvelope",
     "Enter a date" : "Voeg een datum toe",
-    "Uploading attachments …" : "Bijlage aan het uploaden ...",
-    "Sending …" : "Versturen ...",
-    "Error sending your message" : "Fout bij het versturen van jouw bericht",
-    "Go back" : "Ga terug",
-    "Retry" : "Opnieuw proberen",
-    "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
-    "Send anyway" : "Toch verzenden",
-    "Message sent!" : "Bericht verzonden!",
-    "Add share link from {productName} Files" : "Toevoegen deellink van {productName} Bestanden",
-    "Send" : "Versturen",
-    "Encrypt and send" : "Versleutelen en versturen",
-    "Send unencrypted" : "Verstuur onversleuteld",
     "Message {id} could not be found" : "Bericht {id} kon niet worden gevonden",
-    "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
     "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
     "Choose a file to share as a link" : "Kies een bestand om als link te delen",
-    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["De bijlage overschrijdt de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link.","De bijlagen overschrijden de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link."],
-    "No message found yet" : "Nog geen berichten gevonden",
-    "Set up an account" : "Maak een account aan",
+    "Choose" : "Kies",
+    "_{count} attachment_::_{count} attachments_" : ["{count} bijlagen","{count} bijlagen"],
+    "Confirm" : "Bevestigen",
     "Plain text" : "Platte tekst",
     "Rich text" : "Rijke tekst",
     "No messages in this mailbox" : "Geen berichten in deze inbak",
+    "No messages" : "Geen berichten",
     "Draft: " : "Concept:",
     "Unfavorite" : "Favoriet weghalen",
     "Favorite" : "Favoriet",
@@ -118,22 +123,24 @@ OC.L10N.register(
     "Unimportant" : "Onbelangrijk",
     "Mark not spam" : "Markeer als geen-spam",
     "Mark as spam" : "Markeren als spam",
-    "Unselect" : "Deselecteren",
-    "Select" : "Selecteer",
     "Edit tags" : "Bewerken tags",
-    "Move" : "Verplaatsen",
     "Move thread" : "Verplaats draadje",
-    "More actions" : "Meer acties",
     "Delete thread" : "Verwijder draadje",
+    "More actions" : "Meer acties",
+    "Back" : "Terug",
     "Edit as new message" : "Bewerk als nieuw bericht",
     "Create event" : "Creëer afspraak",
+    "Create task" : "Aanmaken taak",
     "Blind copy recipients only" : "Alleen ontvangers van blinde kopie",
+    "Set reminder for later today" : "Herinnering voor later vandaag instellen",
+    "Set reminder for tomorrow" : "Herinnering voor morgen instellen",
+    "Set reminder for this weekend" : "Herinnering voor het weekend instellen",
+    "Set reminder for next week" : "Herinnering instellen voor volgende week",
     "No trash mailbox configured" : "Geen verwijderde berichtenmap ingesteld",
     "Could not delete message" : "Kon bericht niet verwijderen",
-    "Forward" : "Doorsturen",
     "Load more" : "Laad meer",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["Markeer {number} ongelezen","Markeer {number} ongelezen"],
     "_Mark {number} read_::_Mark {number} read_" : ["Markeren {number} als gelezen","Markeren {number} als gelezen"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Markeer {number} ongelezen","Markeer {number} ongelezen"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Markeer {number} als niet belangrijk","Markeer {number} als belangrijk"],
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markeer {number} als niet belangrijk","Mark {number} as unimportant"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Favoriet weghalen {number}","Favoriet weghalen {number}"],
@@ -141,22 +148,26 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["De-selecteren {number}","De-selecteren {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Verplaatsen {number} draadje","Verplaatsen {number} draadjes"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Doorsturen {number} als bijlage","Doorsturen {number} als bijlage"],
-    "_Delete {number} thread_::_Delete {number} threads_" : ["Verwijderen {number} draadje","Verwijderen {number} draadjes"],
     "Report this bug" : "Meld deze fout",
     "All day" : "Alle dagen",
+    "Description" : "Omschrijving",
     "Create" : "Aanmaken",
     "Event created" : "Afspraak aangemaakt",
     "Could not create event" : "Kon afspraak niet creëren",
+    "Select" : "Selecteer",
     "Comment" : "Notitie",
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
     "More options" : "Meer opties",
+    "domain" : "domein",
+    "Remove" : "Verwijderen",
+    "individual" : "individueel",
+    "Itinerary for {type} is not supported yet" : "route voor {type} wordt nog niet ondersteund",
     "Could not open mailbox" : "Kon postbus niet openen",
     "Loading messages …" : "Laden berichten ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexeren van je berichten. Dit kan wat tijd kosten voor grote brievenbussen.",
     "Choose target mailbox" : "Kies doel postbus",
     "No more submailboxes in here" : "Niet meer subpostbussen hier",
-    "Choose" : "Kies",
     "Important info" : "Belangrijke informatie",
     "Other" : "Ander",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Berichten zullen automatisch als belangrijk gemarkeerd worden, gebaseerd op met welke berichten je gewerkt hebt of welke je als belangrijk hebt gemarkeerd. In het begin moet je misschien handmatig de belangrijkheid aanpassen om het systeem in te leren, maar het wordt beter met de tijd.",
@@ -164,22 +175,20 @@ OC.L10N.register(
     "Notify the sender" : "Informeer de afzender",
     "You sent a read confirmation to the sender of this message." : "Je hebt een leesbevestiging aan de afzender van dit bericht gestuurd.",
     "Could not send mdn" : "Kon mdn niet versturen",
-    "Reply" : "Antwoord",
-    "Reply to sender only" : "Antwoord alleen op afzender",
+    "Forward" : "Doorsturen",
     "Move message" : "Verplaats bericht",
     "View source" : "Bekijk bron",
     "Download thread data for debugging" : "Download draadgegevens voor debuggen",
-    "Message source" : "Bericht brontekst",
     "Message body" : "Berichttekst",
+    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
     "Import into calendar" : "Toevoegen aan agenda",
     "Download attachment" : "Download bijlage",
     "Save to Files" : "Opslaan in Bestanden",
     "Unnamed" : "Onbenoemd",
     "Embedded message" : "Ingebed bericht",
-    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
+    "Choose a folder to store the attachments in" : "Selecteer een folder waarin de bijlagen opgeslagen moeten worden",
     "Save all to Files" : "Sla alles op in Bestanden",
     "Download Zip" : "Download Zip",
-    "Choose a folder to store the attachments in" : "Selecteer een folder waarin de bijlagen opgeslagen moeten worden",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Dit bericht is versleuteld met PGP. Installeer Mailvelope om het te ontcijferen.",
     "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
     "Show images" : "Tonen afbeeldingen",
@@ -188,6 +197,7 @@ OC.L10N.register(
     "Always show images from {domain}" : "Afbeeldingen van {domain} altijd tonen",
     "Message frame" : "Berichtenkader",
     "Quoted text" : "Geciteerde tekst",
+    "Move" : "Verplaatsen",
     "Moving" : "Verplaatsen",
     "Moving thread" : "Verplaatsen draadje",
     "Moving message" : "Verplaatsen bericht",
@@ -202,7 +212,6 @@ OC.L10N.register(
     "Not supported by the server" : "Niet ondersteund door de server",
     "{usage} of {limit} used" : "{usage} van {limit} gebruikt",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Het account voor {email} en alle gecachte data zal verwijderd worden van Nextcloud, maar niet van je e-mailprovider.",
-    "Remove account {email}" : "Verwijder account {email}",
     "Remove {email}" : "Verwijder {email}",
     "Show all subscribed mailboxes" : "Toon alle geabonneerde postbussen",
     "Show all mailboxes" : "Toon alle postbussen",
@@ -210,8 +219,8 @@ OC.L10N.register(
     "Mark all as read" : "Alles als gelezen markeren",
     "Mark all messages of this mailbox as read" : "Markeer alle berichten in deze berichtenbox als gelezen",
     "Add submailbox" : "Toevoegen subpostbus",
-    "Edit name" : "Bewerken naam",
-    "Clear cache" : "Leegmaken cache",
+    "Rename" : "Hernoemen",
+    "Clear cache" : "Cache leegmaken",
     "Clear locally cached data, in case there are issues with synchronization." : "Maak de lokale gegevenscache schoon, als er problemen zijn bij synchronisatie.",
     "Subscribed" : "Geabonneerd",
     "Sync in background" : "Synchroniseer op de achtergrond",
@@ -220,27 +229,36 @@ OC.L10N.register(
     "Delete mailbox {name}" : "Verwijder postbus {name}",
     "An error occurred, unable to rename the mailbox." : "Er is een fout opgetreden, de naam van de mailbox kon niet worden gewijzigd.",
     "_{total} message_::_{total} messages_" : ["{total} bericht","{total} berichten"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ongelezen van de {total}","{unread} ongelezen van de {total}"],
     "Outbox" : "Uitbak",
     "New message" : "Nieuw bericht",
+    "Error sending your message" : "Fout bij het versturen van jouw bericht",
+    "Retry" : "Opnieuw proberen",
+    "Uploading attachments …" : "Bijlage aan het uploaden ...",
+    "Sending …" : "Versturen ...",
+    "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
+    "Send anyway" : "Toch verzenden",
+    "Edit message" : "Bewerk bericht",
     "Draft" : "Concept",
-    "No message selected" : "Geen bericht geselecteerd",
+    "Reply" : "Antwoord",
+    "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
     "Message" : "Bericht",
     "Oh Snap!" : "O nee!",
-    "Delete" : "Verwijderen",
     "Contacts with this address" : "Contactpersonen met dit adres",
     "Add to Contact" : "Toevoegen aan contactpersoon",
     "New Contact" : "Nieuwe contactpersoon",
     "Copy to clipboard" : "Kopiëren naar het klembord",
     "Contact name …" : "Naam contactpersoon ...",
     "Add" : "Toevoegen",
-    "Disabled" : "Uitgeschakeld",
-    "Enabled" : "Ingeschakeld",
-    "Sieve Host" : "Sieve-server",
-    "Sieve Security" : "Sieve Security",
+    "Close" : "Sluit",
+    "Body" : "Body",
+    "Date" : "Datum",
+    "Tags" : "Tags",
+    "Select tags" : "Kies tags",
+    "Last 7 days" : "Laatste 7 dagen",
+    "Clear" : "Terug",
     "Sieve Port" : "Sieve poort",
-    "Sieve Credentials" : "Sieve inloggegevens",
-    "IMAP Credentials" : "IMAP inloggegevens",
+    "IMAP credentials" : "IMAP inloggegevens",
     "Custom" : "Maatwerk",
     "Sieve User" : "Sieve gebruiker",
     "Sieve Password" : "Sieve Wachtwoord",
@@ -249,26 +267,24 @@ OC.L10N.register(
     "Signature …" : "Handtekening ...",
     "Save signature" : "Handtekening opslaan",
     "Place signature above quoted text" : "Plaats handtekening boven de aangehaalde tekst",
-    "Add default tags" : "Voeg standaard tags toe",
-    "Rename tag" : "Hernoem tag",
     "Saving new tag name …" : "Sla nieuw tag op ...",
-    "Set" : "Stel in",
-    "Unset" : "Schakel uit",
+    "Delete tag" : "Verwijderen tag",
+    "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
+    "Add default tags" : "Voeg standaard tags toe",
     "Add tag" : "Toevoegen tag",
     "Saving tag …" : "Opslaan tag ...",
     "Tag already exists" : "Markering bestaat al",
     "An error occurred, unable to create the tag." : "Er trad een fout op, tag kon niet worden gecreëerd.",
-    "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
+    "Not found" : "Niet gevonden",
     "Could not load your message thread" : "Kon je berichtendraad niet laden",
+    "Unsubscribe" : "Afmelden",
+    "Reply to sender only" : "Antwoord alleen op afzender",
     "Mark as unread" : "Markeren als ongelezen",
     "Mark as read" : "Markeren als gelezen",
     "Delete message" : "Bericht verwijderen",
-    "Not found" : "Niet gevonden",
-    "Remove" : "Verwijderen",
+    "Message source" : "Bericht brontekst",
     "No senders are trusted at the moment." : "Er zijn nu geen vertrouwder afzenders.",
     "Could not remove trusted sender {sender}" : "Kon vertrouwde afzender niet verwijderen {afzender}",
-    "individual" : "individueel",
-    "domain" : "domein",
     "(organizer)" : "(organisator)",
     "Untitled event" : "Naamloos evenement",
     "Import into {calendar}" : "Importeer in {calendar}",
@@ -279,6 +295,12 @@ OC.L10N.register(
     "Train" : "Trein",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} van {depStation} naar {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trein van {depStation} naar {arrStation}",
+    "Flag" : "lag",
+    "Operator" : "Operator",
+    "Filter name" : "Filternaam",
+    "Actions" : "Acties",
+    "New action" : "Nieuwe actie",
+    "Priority" : "Prioriteit",
     "Mail app" : "Mail toepassing",
     "The mail app allows users to read mails on their IMAP accounts." : "Met de mail-app kunnen gebruikers e-mails lezen op hun IMAP-accounts.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hier vind je de instellingen voor de instantie. Gebruikersspecifieke instellingen zijn te vinden in de app zelf (linksonder).",
@@ -316,13 +338,14 @@ OC.L10N.register(
     "Error saving anti spam email addresses" : "Fout bij het opslaan van anti-spam e-mail adressen",
     "Successfully deleted anti spam reporting email" : "Anti-spam rapporteer e-mail succesvol toegevoegd",
     "Error deleting anti spam reporting email" : "Fout bij het verwijderen van anti-spam rapporteer email",
+    "Client ID" : "Client ID",
+    "Client secret" : "Client secret",
     "Domain Match: {provisioningDomain}" : "Domein overeenkomst: {provisioningDomain}",
     "Email: {email}" : "E-mail: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} op {host}:{port} ({ssl} versleuteling)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} op {host}:{port} ({ssl} versleuteling)",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} op {host}:{port} ({ssl} versleuteling)",
     "Configuration for \"{provisioningDomain}\"" : "Configuratie voor \"{provisioningDomain}\"",
-    "General" : "Algemeen",
     "Provisioning domain" : "Provisioningdomein",
     "Email address template" : "E-mailadres sjabloon",
     "IMAP" : "IMAP",
@@ -341,20 +364,17 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "De-provision & verwijder config",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% en %EMAIL% zal worden vervangen door de gebruikers UID en e-mail",
     "With the settings above, the app will create account settings in the following way:" : "Met de bovenstaande instellingen maakt de app op de volgende manier accountinstellingen:",
-    "Keyboard shortcut" : "Sneltoets",
-    "Keyboard shortcuts" : "Sneltoetsen",
-    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mailervaring met deze handige snelkoppelingen.",
-    "Compose new message" : "Opstellen nieuw bericht",
-    "Newer message" : "Recenter bericht",
-    "Older message" : "Ouder bericht",
-    "Toggle star" : "Omschakelen ster",
-    "Toggle unread" : "Omschakelen ongelezen",
-    "Search" : "Zoeken",
-    "Refresh" : "Verversen",
+    "E-mail address" : "E-mailadres",
+    "Valid until" : "Geldig tot",
+    "Certificate" : "Certificaat",
+    "Submit" : "Verwerken",
+    "Account connected" : "Account verbonden",
     "Connect your mail account" : "Verbind je e-mailaccount",
-    "Itinerary for {type} is not supported yet" : "route voor {type} wordt nog niet ondersteund",
+    "Next week – {timeLocale}" : "Volgende week - {timeLocale}",
+    "This weekend – {timeLocale}" : "Dit weekend - {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Morgen - {timeLocale}",
+    "Later today – {timeLocale}" : "Later vandaag – {timeLocale}",
     "All" : "Alle",
-    "Archive" : "Archiveer",
     "Drafts" : "Concepten",
     "Favorites" : "Favorieten",
     "Priority inbox" : "Prioriteit",
@@ -379,6 +399,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
     "Redirect" : "Omleiden",
     "The link leads to %s" : "De link verwijst naar %s",
-    "Continue to %s" : "Verder naar %s"
+    "Continue to %s" : "Verder naar %s",
+    "Sieve filter rules" : "Sieve filterregels",
+    "Sieve filter server" : "Sieve filterserver",
+    "Unselect" : "Deselecteren"
 },
 "nplurals=2; plural=(n != 1);");
