@@ -12,31 +12,33 @@ OC.L10N.register(
     "Connect" : "Kopla til",
     "Signature" : "Signatur",
     "Cancel" : "Avbryt",
+    "General" : "Generelt",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
     "Delete" : "Ta bort",
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Last inn på nytt",
     "Choose" : "Vel",
     "Favorite" : "Favoritt",
-    "Select" : "Vel",
     "Back" : "Tilbake",
     "Description" : "Skildring",
     "Create" : "Lag",
+    "Select" : "Vel",
     "Comment" : "Kommentér",
+    "Remove" : "Fjern",
     "Other" : "Anna",
-    "Reply" : "Svare",
     "Move" : "Move",
     "Quota" : "Kvote",
     "Saving" : "Lagrar",
+    "Rename" : "Endra namn",
     "Retry" : "Forsøk att",
+    "Reply" : "Svare",
     "Add" : "Legg til",
     "Close" : "Lat att",
     "Date" : "Dato",
     "Tags" : "Emneord",
-    "Disabled" : "Deaktivert",
-    "Remove" : "Fjern",
+    "Actions" : "Handlingar",
     "Client ID" : "Klient-ID",
-    "General" : "Generelt",
     "User" : "Bruker",
     "Host" : "Tenar",
     "Port" : "Port",
