@@ -3,14 +3,16 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Messàgiu incorporadu %s",
     "Important mail" : "Messàgiu de posta importante",
+    "No message found yet" : "Ancora perunu messàgiu agatadu",
+    "Set up an account" : "Cunfigura unu contu",
     "Unread mail" : "Posta no lèghida",
     "Important" : "Importante",
     "Work" : "Traballu",
     "Personal" : "Personale",
     "To Do" : "De fàghere",
     "Later" : "Luego",
-    "Mails" : "Messàgios de posta",
     "Mail" : "Posta ",
+    "Mails" : "Messàgios de posta",
     "💌 A mail app for Nextcloud" : "💌 Un'aplicatzione de posta pro Nextcloud",
     "Drafts are saved in:" : "Is brutacòpias sunt sarvadas in:",
     "Sent messages are saved in:" : "Is messàgios imbiados sunt sarvados in:",
@@ -19,7 +21,7 @@ OC.L10N.register(
     "Name" : "Nùmene",
     "Password" : "Crae",
     "Manual" : "Manuale",
-    "IMAP Settings" : "Impostatziones IMAP ",
+    "IMAP Settings" : "Cunfiguratzione IMAP ",
     "IMAP Host" : "Retzidore IMAP ",
     "IMAP Security" : "Seguresa IMAP ",
     "None" : "Perunu",
@@ -28,7 +30,7 @@ OC.L10N.register(
     "IMAP Port" : "Porta IMAP ",
     "IMAP User" : "Utente IMAP ",
     "IMAP Password" : "Crae IMAP ",
-    "SMTP Settings" : "Impostatziones SMTP",
+    "SMTP Settings" : "Cunfiguratzione SMTP",
     "SMTP Host" : "Retzidore SMTP ",
     "SMTP Security" : "Seguresa SMTP ",
     "SMTP Port" : "Porta SMTP ",
@@ -36,32 +38,43 @@ OC.L10N.register(
     "SMTP Password" : "Crae SMTP",
     "Save" : "Sarva",
     "Connect" : "Connete",
-    "Account settings" : "Impostatziones de contu",
-    "Change name" : "Càmbia nùmene",
+    "Account settings" : "Cunfiguratzione de su contu",
     "Signature" : "Firma",
     "A signature is added to the text of new messages and replies." : "S'agiunghet una firma a su testu de is messàgios noos e de is respostas.",
     "Writing mode" : "Modalidade de iscritura",
     "Preferred writing mode for new messages and replies." : "Modalidade de iscritura preferida pro is messàgios noos e de is respostas.",
     "Default folders" : "Cartellas predefinidas",
-    "The folders to use for drafts, sent messages and deleted messages." : "Is cartellas de impreare pro brutacòpias, messàgios imbiados e messàgios cantzellados.",
-    "Sieve filter rules" : "Règulas de filtru Sieve",
-    "Trusted senders" : "Imbiantes afidàbiles",
     "Mail server" : "Serbidore de posta",
-    "Sieve filter server" : "Serbidore de filtru Sieve",
     "Update alias" : "Agiorna identidade",
     "Show update alias form" : "Mustra s'agiornamentu de sa forma de su identidade",
     "Delete alias" : "Cantzella identidade",
+    "Go back" : "Bae in segus",
+    "Change name" : "Càmbia nùmene",
     "Email address" : "Indiritzu de posta eletrònica",
     "Add alias" : "Agiunghe identidade",
     "Create alias" : "Crea identidade",
     "Cancel" : "Annulla",
     "Add mail account" : "Agiunghe contu de posta",
+    "General" : "Generale",
+    "Sorting" : "Assentende",
+    "Newest" : "Prus nou",
     "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
-    "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu",
+    "Register" : "Registra",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
+    "Trusted senders" : "Imbiantes afidàbiles",
+    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
+    "Compose new message" : "Iscrie messàgiu nou",
+    "Newer message" : "Messàgiu prus reghente",
+    "Older message" : "Messàgiu prus betzu",
+    "Toggle star" : "Ativa/disativa s'istella",
+    "Toggle unread" : "Ativa/disativa non lèghidu",
+    "Archive" : "Cartella",
+    "Delete" : "Cantzella",
+    "Search" : "Chirca",
+    "Send" : "Imbia",
+    "Refresh" : "Agiorna",
     "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus.",
-    "Automatically classify importance of new email" : "Classificare de manera automàtica s'importu de unu messàgiu de posta eletrònica nou",
     "Could not update preference" : "No at fatu a agiornare sa preferèntzia",
     "From" : "Dae",
     "Select account" : "Seletziona contu",
@@ -69,7 +82,6 @@ OC.L10N.register(
     "Contact or email address …" : "Cuntatu o indiritzu de posta ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Perunu cuntatu agatadu.",
     "Subject" : "Ogetu",
     "Subject …" : "Ogetu",
     "This message came from a noreply address so your reply will probably not be read." : "Custu messàgiu est arribadu dae unu indiritzu chena resposta, tando est fàtzile chi sa resposta tua no s'at a lèghere.",
@@ -77,76 +89,71 @@ OC.L10N.register(
     "Write message …" : "Iscrie messàgiu ...",
     "Saving draft …" : "Sarvende sa brutacòpia ...",
     "Draft saved" : "Brutacòpia sarvada",
+    "Enable formatting" : "Ativa formatatzione",
     "Upload attachment" : "Càrriga alligongiadu",
     "Add attachment from Files" : "Agiunghe alligongiadu dae Archìvios",
-    "Enable formatting" : "Ativa formatatzione",
     "Request a read receipt" : "Pedi una cunfirma de letura",
     "Encrypt message with Mailvelope" : "Tzifra messàgiu cun Mailvelope",
     "Enter a date" : "Inserta una data",
-    "Uploading attachments …" : "Carrighende alligongiadu ...",
-    "Sending …" : "Imbiende ...",
-    "Error sending your message" : "Errore in s'imbiu de su messàgiu",
-    "Go back" : "Bae in segus",
-    "Retry" : "Torra a proare",
-    "Warning sending your message" : "Avisu in s'imbiu de su messàgiu",
-    "Send anyway" : "Imbia a su pròpiu",
-    "Message sent!" : "Messàgiu imbiadu!",
-    "Add share link from {productName} Files" : "Agiunghe unu ligòngiu de cumpartzidura dae {productName} Archìvios",
-    "Send" : "Imbia",
-    "Encrypt and send" : "Tzifra e imbia",
-    "Send unencrypted" : "Imbia chene tzifrare",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
-    "No sent mailbox configured. Please pick one in the account settings." : "Peruna casella de posta imbiada cunfigurada. Sèbera•nde una in is impostatziones de su contu.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Choose a file to add as attachment" : "Sèbera un'archìviu de agiùnghere comente alligongiadu",
     "Choose a file to share as a link" : "Sèbera un'archìviu de cumpartzire comente ligòngiu",
-    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu.","Is alligongiados propassant sa mannària permìtida de {size}. Cumpartzi is archìvios cun unu ligòngiu."],
-    "No message found yet" : "Ancora perunu messàgiu agatadu",
-    "Set up an account" : "Imposta unu contu",
+    "Choose" : "Sèbera",
+    "Confirm" : "Cunfirma",
     "Plain text" : "Testu simple",
     "Rich text" : "Testu formatadu",
     "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
+    "No messages" : "Perunu messàgiu",
     "Draft: " : "Brutacòpia:",
     "Unfavorite" : "Boga dae is preferidos",
     "Favorite" : "Preferidu",
+    "Unread" : "De lèghere",
     "Read" : "Leghe",
     "Mark not spam" : "Marca comente no spam",
     "Mark as spam" : "Marca comente spam",
-    "Unselect" : "Deseletziona",
-    "Select" : "Seletziona",
     "Edit tags" : "Modìfica etichetas",
-    "Move" : "Tràmuda",
     "Move thread" : "Tràmuda dibata",
-    "More actions" : "Àteras atziones",
     "Delete thread" : "Cantzella dibata",
+    "More actions" : "Àteras atziones",
+    "Back" : "In segus",
     "Edit as new message" : "Modìfica comente messàgiu nou",
     "Create event" : "Crea eventu",
+    "Create task" : "Crea faina",
     "Blind copy recipients only" : "Isceti persones destinatàrias in còpia cuada",
+    "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
+    "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
+    "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
+    "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
     "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
     "Could not delete message" : "No at fatu a cantzellare su messàgiu",
-    "Forward" : "Torra a imbiare",
     "Load more" : "Càrriga àteru",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} no lèghidos","Marca {number} non lèghidos"],
     "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} lèghidos","Marca {number} lèghidos"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} no lèghidos","Marca {number} non lèghidos"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Boga dae is preferidos {number}","Boga dae is preferidos {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["Agiunghe a is preferidos","Agiunghe a is Preferidos {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["Deseletziona {number}","Deseletziona {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Tràmuda {number} dibatas","Tràmuda {number} dibatas"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} comente alligongiados","Inoltra {number} comente alligongiadu"],
-    "_Delete {number} thread_::_Delete {number} threads_" : ["Cantzella {number} dibatas","Cantzella {number} dibatas"],
     "Report this bug" : "Signala cust'errore",
     "All day" : "Totu sa die",
+    "Description" : "Descritzione",
     "Create" : "Crea",
     "Could not create event" : "No at fatu a creare s'eventu",
+    "Select" : "Seletziona",
     "Comment" : "Cummentu",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
     "More options" : "Àteras optziones",
+    "domain" : "domìniu",
+    "Remove" : "Boga",
+    "email" : "posta eletrònica",
+    "Add internal address" : "Agiunghe indiritzu internu",
+    "individual" : "individuale",
+    "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
     "Could not open mailbox" : "No at fatu a abèrrere sa casella de posta",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Inditzizende is messàgios. S'at a pòdere istentare unu pagu de prus cun casellas de posta prus mannas.",
     "Choose target mailbox" : "Sèbera casella de posta de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
-    "Choose" : "Sèbera",
     "Important info" : "Informatzione importante",
     "Other" : "Àteru",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
@@ -154,30 +161,29 @@ OC.L10N.register(
     "Notify the sender" : "Notificare a sa persone chi imbiat",
     "You sent a read confirmation to the sender of this message." : "As imbiadu una cunfirma de letura a sa persone chi at imbiadu custu messàgiu.",
     "Could not send mdn" : "No at fatu a imbiare mdn",
-    "Reply" : "Responde",
-    "Reply to sender only" : "Responde isceti a chi at imbiadu",
+    "Forward" : "Torra a imbiare",
     "Move message" : "Tràmuda messàgiu",
     "View source" : "Visualiza sa fonte",
     "Download thread data for debugging" : "Iscàrriga is datos de sa dibata pro sa curretzione",
-    "Message source" : "Fonte de su messàgiu",
     "Message body" : "Corpus de su messàgiu",
+    "Choose a folder to store the attachment in" : "Sèbera una cartella in ue allogare s'alligongiadu",
     "Import into calendar" : "Importa in su calendàriu",
     "Download attachment" : "Iscàrriga alligongiadu",
     "Save to Files" : "Sarva in Archìvios",
     "Unnamed" : "Chene nùmene",
     "Embedded message" : "Messàgiu incorporadu ",
-    "Choose a folder to store the attachment in" : "Sèbera una cartella in ue allogare s'alligongiadu",
+    "Choose a folder to store the attachments in" : "Sèbera una cartella in ue allogare is alligongiados",
     "Save all to Files" : "Sarva totu in Archìvios",
     "Download Zip" : "Iscàrriga Zip",
-    "Choose a folder to store the attachments in" : "Sèbera una cartella in ue allogare is alligongiados",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Custu messàgiu est tzifradu cun PGP. Installa Mailvelope pro ddu detzifrare.",
-    "The images have been blocked to protect your privacy." : "Is imàgines sunt istadas blocadas pro amparare sa privadesa tua.",
-    "Show images" : "Mustra imàgines",
-    "Show images temporarily" : "Mustra imàgines in manera temporale",
-    "Always show images from {sender}" : "Mustra semper imàgines dae {sender}",
-    "Always show images from {domain}" : "Mustra semper imàgines dae {domain}",
+    "The images have been blocked to protect your privacy." : "Is immàgines sunt istadas blocadas pro amparare sa riservadesa tua.",
+    "Show images" : "Mustra immàgines",
+    "Show images temporarily" : "Mustra immàgines in manera temporale",
+    "Always show images from {sender}" : "Mustra semper immàgines dae {sender}",
+    "Always show images from {domain}" : "Mustra semper immàgines dae {domain}",
     "Message frame" : "Ricuadru de se messàgiu",
     "Quoted text" : "Testu tzitadu",
+    "Move" : "Tràmuda",
     "Moving" : "Tramudende",
     "Moving thread" : "Tramudende sa dibata",
     "Moving message" : "Tramudende su messàgiu",
@@ -192,7 +198,6 @@ OC.L10N.register(
     "Not supported by the server" : "No suportadu dae su serbidore",
     "{usage} of {limit} used" : "{usage} de {limit} impreadu",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Su contu pro {email} e is datos de posta eletrònica allogados in sa memòria temporànea s'ant a bogare dae Nextcloud, ma no dae su frunidore de posta eletrònica tuo.",
-    "Remove account {email}" : "Boga·nche contu {email}",
     "Remove {email}" : "Boga•nche {email}",
     "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
     "Show all mailboxes" : "Mustra totu is casellas de posta",
@@ -200,7 +205,6 @@ OC.L10N.register(
     "Mark all as read" : "Marca totu comente lèghidu",
     "Mark all messages of this mailbox as read" : "Marca totu is messàgios de custa casella de posta comente lèghidos",
     "Add submailbox" : "Agiunghe una sutacasella de posta",
-    "Edit name" : "Modìfica nùmene",
     "Clear cache" : "Lìmpia memòria temporànea",
     "Clear locally cached data, in case there are issues with synchronization." : "Lìmpia is datos locales allogados in sa memòria temporànea, s'in casu mai b'apant problemas cun sa sincronizatzione.",
     "Subscribed" : "Sutaiscritu",
@@ -210,48 +214,55 @@ OC.L10N.register(
     "Delete mailbox {name}" : "Cantzella casella de posta {name}",
     "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
     "New message" : "Messàgiu nou",
-    "No message selected" : "Perunu messàgiu seletzionadu",
+    "Error sending your message" : "Errore in s'imbiu de su messàgiu",
+    "Retry" : "Torra a proare",
+    "Uploading attachments …" : "Carrighende alligongiadu ...",
+    "Sending …" : "Imbiende ...",
+    "Warning sending your message" : "Avisu in s'imbiu de su messàgiu",
+    "Send anyway" : "Imbia a su pròpiu",
+    "Reply" : "Responde",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Message" : "Messàgiu",
     "Oh Snap!" : "Lampu!",
-    "Delete" : "Cantzella",
     "Contacts with this address" : "Cuntatos cun custu indiritzu",
     "Add to Contact" : "Agiunghe a Cuntatu",
     "New Contact" : "Cuntatu nou",
     "Copy to clipboard" : "Còpia in is punta de billete",
     "Contact name …" : "Nùmene de su cuntatu ...",
     "Add" : "Agiunghe",
-    "Disabled" : "Disativadu",
-    "Enabled" : "Ativadu",
-    "Sieve Host" : "Retzidore Sieve",
-    "Sieve Security" : "Seguresa Sieve",
+    "Close" : "Serra",
+    "Body" : "Corpus",
+    "Date" : "Data",
+    "Tags" : "Etichetas",
+    "Select tags" : "Seletziona etichetas",
+    "Last 7 days" : "Ùrtimas 7 dies",
+    "Clear" : "Lìmpia",
     "Sieve Port" : "Porta Sieve",
-    "Sieve Credentials" : "Credentziales Sieve",
-    "IMAP Credentials" : "Credentziales IMAP",
     "Custom" : "Personaliza",
     "Sieve User" : "Utente Sieve",
     "Sieve Password" : "Crae Sieve",
-    "Save sieve settings" : "Sarva impostatziones sieve",
+    "Save sieve settings" : "Sarva cunfiguratzione sieve",
     "Save sieve script" : "Sarva cumandos sieve",
     "Signature …" : "Firma ...",
     "Save signature" : "Sarva firma",
     "Place signature above quoted text" : "Pone sa firma subra su testu tzitadu",
-    "Set" : "Imposta",
-    "Unset" : "No impostadu",
+    "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
     "Add tag" : "Agiunghe eticheta",
     "Saving tag …" : "Sarvende s'eticheta ...",
     "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
+    "Not found" : "No agatadu",
     "Could not load your message thread" : "No at fatu a carrigare su messàgiu tuo in sa dibata",
+    "Unsubscribe" : "Disiscrie·ti",
+    "Reply to sender only" : "Responde isceti a chi at imbiadu",
     "Mark as unread" : "Marca comente non lèghidu",
     "Mark as read" : "Marca comente lèghidu",
     "Delete message" : "Cantzella messàgiu",
-    "Not found" : "No agatadu",
-    "Remove" : "Boga",
+    "Message source" : "Fonte de su messàgiu",
+    "Go to newest message" : "Bae a su messàgiu prus nou",
     "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
     "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
-    "individual" : "individuale",
-    "domain" : "domìniu",
     "(organizer)" : "(persona organizadora)",
     "Untitled event" : "Eventu chene tìtulu",
     "Import into {calendar}" : "Importa in {calendar}",
@@ -262,34 +273,40 @@ OC.L10N.register(
     "Train" : "Trenu",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} dae {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
+    "New filter" : "Filtru nou",
+    "New test" : "Proa noa",
+    "Actions" : "Atziones",
+    "New action" : "Atzione noa",
+    "Priority" : "Prioridade",
     "Mail app" : "Aplicatzione de posta",
     "The mail app allows users to read mails on their IMAP accounts." : "S'aplicatzione de posta permitit a is utentes de lèghere is messàgios de is contos IMAP issoro.",
-    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Inoghe podes agatare is impostatziones pro totu s'istàntzia. Is impostatziones ispetzìficas de s'utente sunt in s'aplicatzione etotu (in bàsciu a manca).",
-    "A provisioning configuration will provision all accounts with a matching email address." : "Un'impostatzione de frunidura at a frunire a totu is contos un'indiritzu de posta eletrònica currispondente.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Inoghe podes agatare sa cunfiguratzione pro totu s'istàntzia. Is cunfiguratziones ispetzìficas de s'utente sunt in s'aplicatzione etotu (in bàsciu a manca).",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Una cunfiguratzione de frunidura at a frunire a totu is contos un'indiritzu de posta eletrònica currispondente.",
     "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Impreende sa wild card (*) in su campu de domìniu de sa frunidura s'at a creare una cunfiguratzione de aplicare a totu is utentes, frunida a is chi no tenent àtera cunfiguratzione. ",
     "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Su mecanismu de frunidura at a dare prioridade a cunfiguratziones ispetzìficas de domìniu subra de sa cunfiguratzione de domìmiu cun wild card.",
     "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "S'incasu mai s'agatet una cunfiguratzione currispondente noa a pustis chi s'utente aiat giai retzidu un'atera cunfiguratzione, cussa noa at a tènnere pretzedèntzia e s'at a frunire a s'utente a càmbiu de s'àtera.",
     "There can only be one configuration per domain and only one wildcard domain configuration." : "B'est isceti una cunfiguratzione pro domìniu e isceti una cunfiguratzione de domìniu cun wild card.",
-    "These settings can be used in conjunction with each other." : "Custas impostatziones s'ant a pòdere impreare in congiuntzione paris sa una cun s'àtera.",
+    "These settings can be used in conjunction with each other." : "Custas optziones s'ant a pòdere impreare in congiuntzione paris sa una cun s'àtera.",
     "If you only want to provision one domain for all users, use the wildcard (*)." : "S'incasu cheres frunire isceti unu domìniu pro totu is utentes, imprea sa wild card (*).",
     "Add new config" : "Agiunghe cunfiguratzione noa",
     "Provision all accounts" : "Fruni a totu is contos",
     "Successfully updated config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" agiornada in manera curreta",
     "Error saving config" : "Errore sarvende sa cunfiguratzione",
     "Saved config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" sarvada",
-    "Could not save provisioning setting" : "No at fatu a sarvare is impostatziones de frunidura",
+    "Could not save provisioning setting" : "Impossìbile sarvare sa cunfiguratzione de frunidura",
     "There was an error when provisioning accounts." : "B'at àpidu un'errore in sa frunidura a is contos.",
     "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "S'at cantzelladu e bogadu sa frunidura a is contos pro \"{domain}\"",
     "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore cantzellende e boghende•nde sa frunidura a is contos pro \"{domain}\"",
     "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Frunidura a is {count} contos fata in manera curreta. ","Frunidura a is {count} contos fata in manera curreta. "],
-    "Reset" : "Torra a impostare",
+    "Reset" : "Ripristina",
+    "Client ID" : "ID cliente",
+    "Client secret" : "Segretu de su cliente",
     "Domain Match: {provisioningDomain}" : "Currispondèntzia de domìniu: {provisioningDomain}",
     "Email: {email}" : "Posta eletrònica: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} in {host}:{port} (tzifradura {ssl})",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} in {host}:{port} (tzifradura {ssl})",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} in {host}:{port} (tzifradura {ssl})",
     "Configuration for \"{provisioningDomain}\"" : "Cunfiguratzione pro \"{provisioningDomain}\"",
-    "General" : "Generale",
     "Provisioning domain" : "Frunidura de su domìniu",
     "Email address template" : "Modellu de s'indiritzu de posta eletrònica",
     "IMAP" : "IMAP",
@@ -306,21 +323,13 @@ OC.L10N.register(
     "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Un'atributu multi balore pro frunire identidades de posta eletrònica. Pro cada balore si creat un'identidade. Is identidades in Nextcloud chi no sunt in sa cartella LDAP si cantzellant.",
     "Save Config" : "Sarva cunfiguratzione",
     "Unprovision & Delete Config" : "Boga•nche sa frunidura e Cantzella Cunfiguratzione",
-    "With the settings above, the app will create account settings in the following way:" : "Cun is impostatziones de antis, s'aplicatzione at a creare is impostatziones de contu in custa manera:",
-    "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
-    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
-    "Speed up your Mail experience with these quick shortcuts." : "Faghe s'esperièntzia de Mail prus lestra cun custos curtziadòrgios.",
-    "Compose new message" : "Iscrie messàgiu nou",
-    "Newer message" : "Messàgiu prus reghente",
-    "Older message" : "Messàgiu prus betzu",
-    "Toggle star" : "Ativa/disativa s'istella",
-    "Toggle unread" : "Ativa/disativa non lèghidu",
-    "Search" : "Chirca",
-    "Refresh" : "Agiorna",
+    "With the settings above, the app will create account settings in the following way:" : "Cun sa cunfiguratzione de antis, s'aplicatzione at a creare sa cunfiguratzione de contu in custa manera:",
+    "E-mail address" : "Indiritzu de posta eletrònica",
+    "Certificate" : "Tzertificadu",
+    "Submit" : "Imbia",
+    "Account connected" : "Contu collegadu",
     "Connect your mail account" : "Connete·ti a su contu de posta tuo",
-    "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
     "All" : "Totu",
-    "Archive" : "Cartella",
     "Drafts" : "Brutacòpias",
     "Favorites" : "Preferidos",
     "Priority inbox" : "Posta retzida cun prioridade",
@@ -345,6 +354,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Incarca inoghe chi no ses torradu a deretare in manera automàtica intro de pagu segundos.",
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
-    "Continue to %s" : "Sighi in %s"
+    "Continue to %s" : "Sighi in %s",
+    "Sieve filter rules" : "Règulas de filtru Sieve",
+    "Sieve filter server" : "Serbidore de filtru Sieve",
+    "Unselect" : "Deseletziona"
 },
 "nplurals=2; plural=(n != 1);");
