@@ -23,78 +23,94 @@ OC.L10N.register(
     "Connecting" : "Duke u lidhur",
     "Save" : "Ruaj",
     "Connect" : "Lidhu",
+    "Password required" : "Kërkohet fjalëkalimi",
+    "Aliases" : "Emërtimet",
     "Signature" : "Nënshkrimi",
-    "Cancel" : "Anullo",
-    "Add mail account" : "Shto llogarinë e postës elektronike",
-    "Select account" : "Përzgjidhni llogari",
-    "Subject" : "Temë",
-    "Upload attachment" : "Ngarko bashkëngjitje",
-    "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
-    "Sending …" : "Po dërgohet …",
     "Go back" : "Shko prapa",
-    "Retry" : "Riprovoni",
-    "Message sent!" : "Mesazhi u dërgua!",
-    "Send" : "Dërgo",
-    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
-    "Unfavorite" : "Jo i/e preferuar",
-    "Favorite" : "I/E Preferuar",
-    "Read" : "Lexoni",
-    "Select" : "Zgjidhni",
-    "Edit tags" : "Përpunoni etiketa",
-    "Move" : "Zhvendos",
-    "More actions" : "Më tepër veprime ",
-    "Forward" : "Përpara",
-    "All day" : "Gjithë ditën",
-    "Create" : "Krijo",
-    "Comment" : "Koment",
-    "Accept" : "Prano",
-    "Decline" : "Refuzo",
-    "Choose" : "Zgjidhni",
-    "Other" : "Tjetër",
-    "Reply" : "Përgjigju",
-    "Import into calendar" : "Importo në kalendar",
-    "Download attachment" : "Shkarko bashkëlidhjen",
-    "Save to Files" : "Ruaje te Skedarët",
-    "Unnamed" : "E paemër",
-    "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
-    "Save all to Files" : "Ruaji të gjitha te Dosjet",
-    "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
-    "Quota" : "Kuotë",
-    "Saving" : "Duke u ruajtur!",
-    "Remove account" : "Fshij llogarinë",
-    "Mark all as read" : "Shënoji krejt si të lexuar",
-    "Clear cache" : "Pastroje fshehtinën",
-    "New message" : "Mesazh i ri",
-    "Message" : "Mesazh",
-    "Delete" : "Fshij",
-    "Copy to clipboard" : "Kopjo në dërrasë ",
-    "Add" : "Shto",
-    "Disabled" : "I çaktivizuar",
-    "Enabled" : "I aktivizuar",
-    "Custom" : "E përshtatur",
-    "Unset" : "E pavendosur",
-    "Add tag" : "Shto etiketim",
-    "Tag already exists" : "Etiketa ekziston",
-    "Mark as unread" : "Shënoje si të palexuar",
-    "Mark as read" : "Shënoje si të lexuar",
-    "Remove" : "Hiq",
-    "Reset" : "Rivendos",
+    "Cancel" : "Anullo",
+    "Accounts" : "Llogari",
+    "Add mail account" : "Shto llogarinë e postës elektronike",
     "General" : "Të përgjithshme",
-    "User" : "Përdorues",
-    "Host" : "Strehë",
-    "Port" : "Porta",
-    "Keyboard shortcut" : "Shkurtore tastiere",
+    "Register" : "Regjistrohu",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
-    "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
     "Toggle star" : "Toggle star",
     "Toggle unread" : "Toggle i pa lexuar",
+    "Archive" : "Arkiva",
+    "Delete" : "Fshij",
     "Search" : "Kërko",
+    "Send" : "Dërgo",
     "Refresh" : "Rifresko",
+    "Select account" : "Përzgjidhni llogari",
+    "Subject" : "Temë",
+    "Upload attachment" : "Ngarko bashkëngjitje",
+    "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
+    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
+    "Choose" : "Zgjidhni",
+    "Confirm" : "Konfirmo",
+    "Unfavorite" : "Jo i/e preferuar",
+    "Favorite" : "I/E Preferuar",
+    "Read" : "Lexoni",
+    "Edit tags" : "Përpunoni etiketa",
+    "More actions" : "Më tepër veprime ",
+    "Back" : "Prapa",
+    "All day" : "Gjithë ditën",
+    "Description" : "Përshkrim",
+    "Create" : "Krijo",
+    "Select" : "Zgjidhni",
+    "Comment" : "Koment",
+    "Accept" : "Prano",
+    "Decline" : "Refuzo",
+    "Remove" : "Hiq",
+    "email" : "postë elektronike",
+    "Other" : "Tjetër",
+    "Forward" : "Përpara",
+    "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
+    "Import into calendar" : "Importo në kalendar",
+    "Download attachment" : "Shkarko bashkëlidhjen",
+    "Save to Files" : "Ruaje te Skedarët",
+    "Unnamed" : "E paemër",
+    "Save all to Files" : "Ruaji të gjitha te Dosjet",
+    "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
+    "Move" : "Zhvendos",
+    "Quota" : "Kuotë",
+    "Saving" : "Duke u ruajtur!",
+    "Remove account" : "Fshij llogarinë",
+    "Mark all as read" : "Shënoji krejt si të lexuar",
+    "Rename" : "Riemërtoje",
+    "Clear cache" : "Pastroje fshehtinën",
+    "New message" : "Mesazh i ri",
+    "Retry" : "Riprovoni",
+    "Sending …" : "Po dërgohet …",
+    "Reply" : "Përgjigju",
+    "Message" : "Mesazh",
+    "Copy to clipboard" : "Kopjo në dërrasë ",
+    "Add" : "Shto",
+    "Close" : "Mbylleni",
+    "Date" : "Data",
+    "Tags" : "Etiketat",
+    "Select tags" : "Përzgjidh etiketat",
+    "Clear" : "Pastro",
+    "Custom" : "E përshtatur",
+    "Delete tag" : "Fshi etiketën",
+    "Add tag" : "Shto etiketim",
+    "Tag already exists" : "Etiketa ekziston",
+    "Mark as unread" : "Shënoje si të palexuar",
+    "Mark as read" : "Shënoje si të lexuar",
+    "Actions" : "Veprimet",
+    "Priority" : "Përparësi",
+    "Reset" : "Rivendos",
+    "Client ID" : "ID klienti",
+    "Client secret" : "E fshehtë klienti",
+    "User" : "Përdorues",
+    "Host" : "Strehë",
+    "Port" : "Porta",
+    "Valid until" : "E vlefshme deri më",
+    "Certificate" : "Çertifikata",
+    "Submit" : "Dërgo",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
-    "Archive" : "Arkiva",
     "Drafts" : "Skica",
     "Favorites" : "Favorites",
     "All inboxes" : "Krejt kutitë e postës",
