@@ -19,60 +19,64 @@ OC.L10N.register(
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
+    "Accounts" : "บัญชี",
+    "General" : "ทั่วไป",
+    "Register" : "ลงทะเบียน",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Archive" : "ที่เก็บถาวร",
+    "Delete" : "ลบ",
+    "Search" : "ค้นหา",
     "Send" : "ส่ง",
+    "Refresh" : "รีเฟรช",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Choose" : "เลือก",
     "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
     "Read" : "อ่าน",
-    "Unselect" : "ยกเลิกการเลือก",
-    "Select" : "เลือก",
     "Edit tags" : "แก้ไขแท็ก",
-    "Forward" : "ส่งต่อ",
+    "Back" : "ย้อนกลับ",
+    "Description" : "คำอธิบาย",
     "Create" : "สร้าง",
+    "Select" : "เลือก",
     "Comment" : "ความคิดเห็น",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
-    "Choose" : "เลือก",
+    "Remove" : "ลบออก",
     "Other" : "อื่น ๆ",
-    "Reply" : "ตอบกลับ",
-    "Unnamed" : "ไม่มีชื่อ",
+    "Forward" : "ส่งต่อ",
     "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
+    "Unnamed" : "ไม่มีชื่อ",
     "Move" : "ย้าย",
     "Moving" : "กำลังย้าย",
     "Quota" : "โควต้า",
     "Saving" : "กำลังบันทึก",
     "Remove account" : "ลบบัญชี",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
+    "Rename" : "เปลี่ยนชื่อ",
     "Clear cache" : "ล้างแคช",
-    "Refresh" : "รีเฟรช",
     "Sending …" : "กำลังส่ง ...",
-    "Delete" : "ลบ",
+    "Reply" : "ตอบกลับ",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
     "Close" : "ปิด",
-    "Tags" : "แท็ก",
-    "Clear" : "ล้าง",
-    "Search" : "ค้นหา",
     "Date" : "วันที่",
-    "Disabled" : "ปิดใช้งาน",
-    "Enabled" : "เปิดใช้งาน",
+    "Tags" : "แท็ก",
+    "Last 7 days" : "ภายใน 7 วัน",
+    "Clear" : "ล้าง",
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
-    "Remove" : "ลบออก",
+    "Not found" : "ไม่พบ",
+    "Actions" : "การกระทำ",
+    "Priority" : "ลำดับความสำคัญ",
     "Reset" : "ตั้งค่าใหม่",
     "Client ID" : "รหัสไคลเอ็นต์",
     "Client secret" : "ข้อมูลลับไคลเอ็นต์",
-    "General" : "ทั่วไป",
     "User" : "ผู้ใช้",
     "Host" : "โฮสต์",
     "Port" : "พอร์ต",
     "Valid until" : "ใช้ได้จนถึง",
     "Certificate" : "ใบรับรอง",
-    "Back" : "ย้อนกลับ",
     "Submit" : "ส่ง",
-    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
-    "Archive" : "ที่เก็บถาวร",
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
@@ -86,6 +90,7 @@ OC.L10N.register(
     "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
-    "Continue to %s" : "ดำเนินการต่อไปที่ %s"
+    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
+    "Unselect" : "ยกเลิกการเลือก"
 },
 "nplurals=1; plural=0;");
