@@ -3,26 +3,9 @@
 declare(strict_types=1);
 
 /**
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Lukas Reschke <lukas@owncloud.com>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Timo Witte <timo.witte@gmail.com>
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014-2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Controller;
@@ -33,11 +16,15 @@ use OCA\Mail\Contracts\IUserPreferences;
 use OCA\Mail\Db\SmimeCertificate;
 use OCA\Mail\Db\TagMapper;
 use OCA\Mail\Service\AccountService;
+use OCA\Mail\Service\AiIntegrations\AiIntegrationsService;
 use OCA\Mail\Service\AliasesService;
+use OCA\Mail\Service\Classification\ClassificationSettingsService;
+use OCA\Mail\Service\InternalAddressService;
 use OCA\Mail\Service\OutboxService;
 use OCA\Mail\Service\SmimeService;
 use OCA\Viewer\Event\LoadViewer;
 use OCP\AppFramework\Controller;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\RedirectResponse;
 use OCP\AppFramework\Http\TemplateResponse;
@@ -50,13 +37,20 @@ use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IRequest;
 use OCP\IURLGenerator;
+use OCP\IUserManager;
 use OCP\IUserSession;
+use OCP\TextProcessing\FreePromptTaskType;
+use OCP\TextProcessing\SummaryTaskType;
+use OCP\User\IAvailabilityCoordinator;
+use Psr\Container\ContainerExceptionInterface;
+use Psr\Container\ContainerInterface;
 use Psr\Log\LoggerInterface;
 use Throwable;
 use function class_exists;
 use function http_build_query;
 use function json_decode;
 
+#[OpenAPI(scope: OpenAPI::SCOPE_IGNORE)]
 class PageController extends Controller {
 	private IURLGenerator $urlGenerator;
 	private IConfig $config;
@@ -73,24 +67,34 @@ class PageController extends Controller {
 	private IEventDispatcher $dispatcher;
 	private ICredentialstore $credentialStore;
 	private SmimeService $smimeService;
+	private AiIntegrationsService $aiIntegrationsService;
+	private IUserManager $userManager;
+	private ?IAvailabilityCoordinator $availabilityCoordinator;
+	private ClassificationSettingsService $classificationSettingsService;
+	private InternalAddressService $internalAddressService;
 
 	public function __construct(string $appName,
-								IRequest $request,
-								IURLGenerator $urlGenerator,
-								IConfig $config,
-								AccountService $accountService,
-								AliasesService $aliasesService,
-								?string          $UserId,
-								IUserSession     $userSession,
-								IUserPreferences $preferences,
-								IMailManager     $mailManager,
-								TagMapper        $tagMapper,
-								IInitialState    $initialStateService,
-								LoggerInterface  $logger,
-								OutboxService    $outboxService,
-								IEventDispatcher $dispatcher,
-								ICredentialStore $credentialStore,
-								SmimeService     $smimeService) {
+		IRequest $request,
+		IURLGenerator $urlGenerator,
+		IConfig $config,
+		AccountService $accountService,
+		AliasesService $aliasesService,
+		?string $UserId,
+		IUserSession $userSession,
+		IUserPreferences $preferences,
+		IMailManager $mailManager,
+		TagMapper $tagMapper,
+		IInitialState $initialStateService,
+		LoggerInterface $logger,
+		OutboxService $outboxService,
+		IEventDispatcher $dispatcher,
+		ICredentialStore $credentialStore,
+		SmimeService $smimeService,
+		AiIntegrationsService $aiIntegrationsService,
+		IUserManager $userManager,
+		ContainerInterface $container,
+		ClassificationSettingsService $classificationSettingsService,
+		InternalAddressService $internalAddressService, ) {
 		parent::__construct($appName, $request);
 
 		$this->urlGenerator = $urlGenerator;
@@ -108,6 +112,17 @@ class PageController extends Controller {
 		$this->dispatcher = $dispatcher;
 		$this->credentialStore = $credentialStore;
 		$this->smimeService = $smimeService;
+		$this->aiIntegrationsService = $aiIntegrationsService;
+		$this->userManager = $userManager;
+		$this->classificationSettingsService = $classificationSettingsService;
+		$this->internalAddressService = $internalAddressService;
+
+		// TODO: inject directly if support for nextcloud < 28 is dropped
+		try {
+			$this->availabilityCoordinator = $container->get(IAvailabilityCoordinator::class);
+		} catch (ContainerExceptionInterface) {
+			$this->availabilityCoordinator = null;
+		}
 	}
 
 	/**
@@ -162,10 +177,25 @@ class PageController extends Controller {
 			$this->tagMapper->getAllTagsForUser($this->currentUserId)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'internal-addresses-list',
+			$this->internalAddressService->getInternalAddresses($this->currentUserId)
+		);
+
+		$this->initialStateService->provideInitialState(
+			'internal-addresses',
+			$this->preferences->getPreference($this->currentUserId, 'internal-addresses', false)
+		);
+
+		$this->initialStateService->provideInitialState(
+			'sort-order',
+			$this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest')
+		);
+
 		try {
 			$password = $this->credentialStore->getLoginCredentials()->getPassword();
 			$passwordIsUnavailable = $password === null || $password === '';
-		} catch (CredentialsUnavailableException | PasswordUnavailableException $e) {
+		} catch (CredentialsUnavailableException|PasswordUnavailableException $e) {
 			$passwordIsUnavailable = true;
 		}
 		$this->initialStateService->provideInitialState(
@@ -179,14 +209,17 @@ class PageController extends Controller {
 				'attachment-size-limit' => $this->config->getSystemValue('app.mail.attachment-size-limit', 0),
 				'app-version' => $this->config->getAppValue('mail', 'installed_version'),
 				'external-avatars' => $this->preferences->getPreference($this->currentUserId, 'external-avatars', 'true'),
+				'layout-mode' => $this->preferences->getPreference($this->currentUserId, 'layout-mode', 'vertical-split'),
 				'reply-mode' => $this->preferences->getPreference($this->currentUserId, 'reply-mode', 'top'),
 				'collect-data' => $this->preferences->getPreference($this->currentUserId, 'collect-data', 'true'),
+				'search-priority-body' => $this->preferences->getPreference($this->currentUserId, 'search-priority-body', 'false'),
 				'start-mailbox-id' => $this->preferences->getPreference($this->currentUserId, 'start-mailbox-id'),
-				'tag-classified-messages' => $this->preferences->getPreference($this->currentUserId, 'tag-classified-messages', 'true'),
+				'tag-classified-messages' => $this->classificationSettingsService->isClassificationEnabled($this->currentUserId) ? 'true' : 'false',
+				'follow-up-reminders' => $this->preferences->getPreference($this->currentUserId, 'follow-up-reminders', 'true'),
 			]);
 		$this->initialStateService->provideInitialState(
 			'prefill_displayName',
-			$user->getDisplayName()
+			$this->userManager->getDisplayName($this->currentUserId),
 		);
 		$this->initialStateService->provideInitialState(
 			'prefill_email',
@@ -232,18 +265,38 @@ class PageController extends Controller {
 			);
 		}
 
-		// Disable scheduled send in frontend if ajax cron is used because it is unreliable
+		// Disable snooze and scheduled send in frontend if ajax cron is used because it is unreliable
 		$cronMode = $this->config->getAppValue('core', 'backgroundjobs_mode', 'ajax');
 		$this->initialStateService->provideInitialState(
 			'disable-scheduled-send',
 			$cronMode === 'ajax',
 		);
+		$this->initialStateService->provideInitialState(
+			'disable-snooze',
+			$cronMode === 'ajax',
+		);
 
 		$this->initialStateService->provideInitialState(
 			'allow-new-accounts',
 			$this->config->getAppValue('mail', 'allow_new_mail_accounts', 'yes') === 'yes'
 		);
 
+		$this->initialStateService->provideInitialState(
+			'llm_summaries_available',
+			$this->aiIntegrationsService->isLlmProcessingEnabled() && $this->aiIntegrationsService->isLlmAvailable(SummaryTaskType::class)
+		);
+
+		$this->initialStateService->provideInitialState(
+			'llm_freeprompt_available',
+			$this->aiIntegrationsService->isLlmProcessingEnabled() && $this->aiIntegrationsService->isLlmAvailable(FreePromptTaskType::class)
+		);
+
+		$this->initialStateService->provideInitialState(
+			'llm_followup_available',
+			$this->aiIntegrationsService->isLlmProcessingEnabled()
+			&& $this->aiIntegrationsService->isLlmAvailable(FreePromptTaskType::class)
+		);
+
 		$this->initialStateService->provideInitialState(
 			'smime-certificates',
 			array_map(
@@ -254,6 +307,13 @@ class PageController extends Controller {
 			),
 		);
 
+		if ($this->availabilityCoordinator !== null) {
+			$this->initialStateService->provideInitialState(
+				'enable-system-out-of-office',
+				$this->availabilityCoordinator->isEnabled(),
+			);
+		}
+
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedFrameDomain('\'self\'');
 		$response->setContentSecurityPolicy($csp);
@@ -351,7 +411,10 @@ class PageController extends Controller {
 	 */
 	public function compose(string $uri): RedirectResponse {
 		$parts = parse_url($uri);
-		$params = ['to' => $parts['path']];
+		$params = [];
+		if (isset($parts['path'])) {
+			$params['to'] = $parts['path'];
+		}
 		if (isset($parts['query'])) {
 			$parts = explode('&', $parts['query']);
 			foreach ($parts as $part) {
