@@ -3,22 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\IMAP;
@@ -27,16 +13,21 @@ use Horde_Imap_Client;
 use Horde_Imap_Client_Base;
 use Horde_Imap_Client_Data_Fetch;
 use Horde_Imap_Client_Exception;
+use Horde_Imap_Client_Exception_NoSupportExtension;
 use Horde_Imap_Client_Fetch_Query;
-use Horde_Imap_Client_Search_Query;
 use Horde_Imap_Client_Ids;
+use Horde_Imap_Client_Search_Query;
 use Horde_Imap_Client_Socket;
-use Horde_Mime_Mail;
+use Horde_Mime_Exception;
+use Horde_Mime_Headers;
 use Horde_Mime_Part;
 use Html2Text\Html2Text;
+use OCA\Mail\Attachment;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\IMAP\Charset\Converter;
 use OCA\Mail\Model\IMAPMessage;
+use OCA\Mail\Service\SmimeService;
 use OCA\Mail\Support\PerformanceLoggerTask;
 use OCP\AppFramework\Db\DoesNotExistException;
 use Psr\Log\LoggerInterface;
@@ -45,18 +36,30 @@ use function array_map;
 use function count;
 use function fclose;
 use function in_array;
+use function is_array;
 use function iterator_to_array;
 use function max;
 use function min;
-use function reset;
+use function OCA\Mail\array_flat_map;
+use function OCA\Mail\chunk_uid_sequence;
 use function sprintf;
 
 class MessageMapper {
 	/** @var LoggerInterface */
 	private $logger;
 
-	public function __construct(LoggerInterface $logger) {
+	private SMimeService $smimeService;
+	private ImapMessageFetcherFactory $imapMessageFactory;
+
+	public function __construct(
+		LoggerInterface $logger,
+		SmimeService $smimeService,
+		ImapMessageFetcherFactory $imapMessageFactory,
+		private Converter $converter,
+	) {
 		$this->logger = $logger;
+		$this->smimeService = $smimeService;
+		$this->imapMessageFactory = $imapMessageFactory;
 	}
 
 	/**
@@ -65,13 +68,14 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function find(Horde_Imap_Client_Base $client,
-						 string $mailbox,
-						 int $id,
-						 bool $loadBody = false): IMAPMessage {
-		$result = $this->findByIds($client, $mailbox, new Horde_Imap_Client_Ids([$id]), $loadBody);
+		string $mailbox,
+		int $id,
+		string $userId,
+		bool $loadBody = false): IMAPMessage {
+		$result = $this->findByIds($client, $mailbox, new Horde_Imap_Client_Ids([$id]), $userId, $loadBody, true);
 
 		if (count($result) === 0) {
-			throw new DoesNotExistException("Message does not exist");
+			throw new DoesNotExistException('Message does not exist');
 		}
 
 		return $result[0];
@@ -89,11 +93,12 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function findAll(Horde_Imap_Client_Socket $client,
-							string $mailbox,
-							int $maxResults,
-							int $highestKnownUid,
-							LoggerInterface $logger,
-							PerformanceLoggerTask $perf): array {
+		string $mailbox,
+		int $maxResults,
+		int $highestKnownUid,
+		LoggerInterface $logger,
+		PerformanceLoggerTask $perf,
+		string $userId): array {
 		/**
 		 * To prevent memory exhaustion, we don't want to just ask for a list of
 		 * all UIDs and limit them client-side. Instead, we can (hopefully
@@ -116,14 +121,11 @@ class MessageMapper {
 			]
 		);
 		$perf->step('mailbox meta search');
-		/** @var int $min */
-		$min = (int) $metaResults['min'];
-		/** @var int $max */
-		$max = (int) $metaResults['max'];
-		/** @var int $total */
-		$total = (int) $metaResults['count'];
+		$min = (int)$metaResults['min'];
+		$total = (int)$metaResults['count'];
 
 		if ($total === 0) {
+			$perf->step('No data in mailbox');
 			// Nothing to fetch for this mailbox
 			return [
 				'messages' => [],
@@ -132,6 +134,17 @@ class MessageMapper {
 			];
 		}
 
+		// This can happen for iCloud
+		if ($metaResults['max'] === null) {
+			$uidnext = $client->status(
+				$mailbox
+			);
+			$perf->step('mailbox meta search for UIDNEXT');
+			$max = (int)$uidnext['uidnext'] - 1; // We need to subtract one for the last used UID
+		} else {
+			$max = ((int)$metaResults['max']);
+		}
+
 		// The inclusive range of UIDs
 		$totalRange = $max - $min + 1;
 		// Here we assume somewhat equally distributed UIDs
@@ -178,18 +191,18 @@ class MessageMapper {
 			 * We take $upper as the lowest known UID as we just found out that
 			 * there is nothing to fetch in $highestKnownUid:$upper
 			 */
-			$logger->debug("Range for findAll did not find any messages. Trying again with a succeeding range");
-			return $this->findAll($client, $mailbox, $maxResults, $upper, $logger, $perf);
+			$logger->debug('Range for findAll did not find any messages. Trying again with a succeeding range');
+			return $this->findAll($client, $mailbox, $maxResults, $upper, $logger, $perf, $userId);
 		}
 		$uidCandidates = array_filter(
 			array_map(
-				function (Horde_Imap_Client_Data_Fetch $data) {
+				static function (Horde_Imap_Client_Data_Fetch $data) {
 					return $data->getUid();
 				},
 				iterator_to_array($fetchResult)
 			),
 
-			function (int $uid) use ($highestKnownUid) {
+			static function (int $uid) use ($highestKnownUid) {
 				// Don't load the ones we already know
 				return $uid > $highestKnownUid;
 			}
@@ -211,7 +224,8 @@ class MessageMapper {
 		$messages = $this->findByIds(
 			$client,
 			$mailbox,
-			new Horde_Imap_Client_Ids($fetchRange)
+			new Horde_Imap_Client_Ids($fetchRange),
+			$userId,
 		);
 		$perf->step('find IMAP messages by UID');
 		return [
@@ -222,13 +236,25 @@ class MessageMapper {
 	}
 
 	/**
+	 * @param Horde_Imap_Client_Base $client
+	 * @param string $mailbox
+	 * @param int[]|Horde_Imap_Client_Ids $ids
+	 * @param string $userId
+	 * @param bool $loadBody
 	 * @return IMAPMessage[]
+	 *
+	 * @throws DoesNotExistException
 	 * @throws Horde_Imap_Client_Exception
+	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
+	 * @throws Horde_Mime_Exception
+	 * @throws ServiceException
 	 */
 	public function findByIds(Horde_Imap_Client_Base $client,
-							  string $mailbox,
-							  Horde_Imap_Client_Ids $ids,
-							  bool $loadBody = false): array {
+		string $mailbox,
+		$ids,
+		string $userId,
+		bool $loadBody = false,
+		bool $runPhishingCheck = false): array {
 		$query = new Horde_Imap_Client_Fetch_Query();
 		$query->envelope();
 		$query->flags();
@@ -241,41 +267,49 @@ class MessageMapper {
 			]
 		);
 
-		/** @var Horde_Imap_Client_Data_Fetch[] $fetchResults */
-		$fetchResults = iterator_to_array($client->fetch($mailbox, $query, [
-			'ids' => $ids,
-		]), false);
+		if (is_array($ids)) {
+			// Chunk to prevent overly long IMAP commands
+			/** @var Horde_Imap_Client_Data_Fetch[] $fetchResults */
+			$fetchResults = array_flat_map(function ($ids) use ($query, $mailbox, $client) {
+				return iterator_to_array($client->fetch($mailbox, $query, [
+					'ids' => $ids,
+				]), false);
+			}, chunk_uid_sequence($ids, 10000));
+		} else {
+			/** @var Horde_Imap_Client_Data_Fetch[] $fetchResults */
+			$fetchResults = iterator_to_array($client->fetch($mailbox, $query, [
+				'ids' => $ids,
+			]), false);
+		}
 
 		$fetchResults = array_values(array_filter($fetchResults, static function (Horde_Imap_Client_Data_Fetch $fetchResult) {
 			return $fetchResult->exists(Horde_Imap_Client::FETCH_ENVELOPE);
 		}));
 
-		if (empty($fetchResults)) {
-			$this->logger->debug("findByIds in $mailbox got " . count($ids) . " UIDs but found none");
+		if ($fetchResults === []) {
+			$this->logger->debug("findByIds in $mailbox got " . count($ids) . ' UIDs but found none');
 		} else {
 			$minFetched = $fetchResults[0]->getUid();
 			$maxFetched = $fetchResults[count($fetchResults) - 1]->getUid();
-			$range = $ids->range_string;
+			if ($ids instanceof Horde_Imap_Client_Ids) {
+				$range = $ids->range_string;
+			} else {
+				$range = 'literals';
+			}
 			$this->logger->debug("findByIds in $mailbox got " . count($ids) . " UIDs ($range) and found " . count($fetchResults) . ". minFetched=$minFetched maxFetched=$maxFetched");
 		}
 
-		return array_map(function (Horde_Imap_Client_Data_Fetch $fetchResult) use ($client, $mailbox, $loadBody) {
-			if ($loadBody) {
-				return new IMAPMessage(
-					$client,
-					$mailbox,
+		return array_map(function (Horde_Imap_Client_Data_Fetch $fetchResult) use ($client, $mailbox, $loadBody, $userId, $runPhishingCheck) {
+			return $this->imapMessageFactory
+				->build(
 					$fetchResult->getUid(),
-					null,
-					$loadBody
-				);
-			} else {
-				return new IMAPMessage(
-					$client,
 					$mailbox,
-					$fetchResult->getUid(),
-					$fetchResult
-				);
-			}
+					$client,
+					$userId,
+				)
+				->withBody($loadBody)
+				->withPhishingCheck($runPhishingCheck)
+				->fetchMessage($fetchResult);
 		}, $fetchResults);
 	}
 
@@ -284,17 +318,21 @@ class MessageMapper {
 	 * @param string $sourceFolderId
 	 * @param int $messageId
 	 * @param string $destFolderId
+	 * @return int the new UID
 	 */
 	public function move(Horde_Imap_Client_Base $client,
-						 string $sourceFolderId,
-						 int $messageId,
-						 string $destFolderId): void {
+		string $sourceFolderId,
+		int $messageId,
+		string $destFolderId): int {
 		try {
-			$client->copy($sourceFolderId, $destFolderId,
+			$mapping = $client->copy($sourceFolderId, $destFolderId,
 				[
 					'ids' => new Horde_Imap_Client_Ids($messageId),
 					'move' => true,
+					'force_map' => true,
 				]);
+
+			return $mapping[$messageId];
 		} catch (Horde_Imap_Client_Exception $e) {
 			$this->logger->debug($e->getMessage(),
 				[
@@ -311,10 +349,10 @@ class MessageMapper {
 	}
 
 	public function markAllRead(Horde_Imap_Client_Base $client,
-								string $mailbox): void {
+		string $mailbox): void {
 		$client->store($mailbox, [
 			'add' => [
-				Horde_Imap_Client::FLAG_SEEN,
+				[Horde_Imap_Client::FLAG_SEEN],
 			],
 		]);
 	}
@@ -323,8 +361,8 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function expunge(Horde_Imap_Client_Base $client,
-							string $mailbox,
-							int $id): void {
+		string $mailbox,
+		int $id): void {
 		try {
 			$client->expunge(
 				$mailbox,
@@ -349,9 +387,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function save(Horde_Imap_Client_Socket $client,
-						 Mailbox $mailbox,
-						 Horde_Mime_Mail $mail,
-						 array $flags = []): int {
+		Mailbox $mailbox,
+		string $mail,
+		array $flags = []): int {
 		$flags = array_merge([
 			Horde_Imap_Client::FLAG_SEEN,
 		], $flags);
@@ -360,7 +398,7 @@ class MessageMapper {
 			$mailbox->getName(),
 			[
 				[
-					'data' => $mail->getRaw(),
+					'data' => $mail,
 					'flags' => $flags,
 				]
 			]
@@ -373,9 +411,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function addFlag(Horde_Imap_Client_Socket $client,
-							Mailbox $mailbox,
-							array $uids,
-							string $flag): void {
+		Mailbox $mailbox,
+		array $uids,
+		string $flag): void {
 		$client->store(
 			$mailbox->getName(),
 			[
@@ -389,9 +427,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function removeFlag(Horde_Imap_Client_Socket $client,
-							   Mailbox $mailbox,
-							   array $uids,
-							   string $flag): void {
+		Mailbox $mailbox,
+		array $uids,
+		string $flag): void {
 		$client->store(
 			$mailbox->getName(),
 			[
@@ -410,8 +448,8 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function getFlagged(Horde_Imap_Client_Socket $client,
-							   Mailbox $mailbox,
-							   string $flag): array {
+		Mailbox $mailbox,
+		string $flag): array {
 		$query = new Horde_Imap_Client_Search_Query();
 		$query->flag($flag, true);
 		$messages = $client->search($mailbox->getName(), $query);
@@ -422,48 +460,69 @@ class MessageMapper {
 	 * @param Horde_Imap_Client_Socket $client
 	 * @param string $mailbox
 	 * @param int $uid
-	 *
+	 * @param string $userId
+	 * @param bool $decrypt
 	 * @return string|null
+	 *
 	 * @throws ServiceException
 	 */
 	public function getFullText(Horde_Imap_Client_Socket $client,
-								string $mailbox,
-								int $uid): ?string {
+		string $mailbox,
+		int $uid,
+		string $userId,
+		bool $decrypt = true): ?string {
 		$query = new Horde_Imap_Client_Fetch_Query();
-		$query->uid();
-		$query->fullText([
-			'peek' => true,
-		]);
+
+		if ($decrypt) {
+			$this->smimeService->addDecryptQueries($query);
+		} else {
+			$query->fullText([ 'peek' => true ]);
+		}
 
 		try {
-			$result = iterator_to_array($client->fetch($mailbox, $query, [
+			$result = $client->fetch($mailbox, $query, [
 				'ids' => new Horde_Imap_Client_Ids($uid),
-			]), false);
+			]);
 		} catch (Horde_Imap_Client_Exception $e) {
 			throw new ServiceException(
-				"Could not fetch message source: " . $e->getMessage(),
-				(int) $e->getCode(),
+				'Could not fetch message source: ' . $e->getMessage(),
+				$e->getCode(),
 				$e
 			);
 		}
 
-		$msg = array_map(function (Horde_Imap_Client_Data_Fetch $result) {
-			return $result->getFullMsg();
-		}, $result);
-
-		if (empty($msg)) {
+		if (($message = $result->first()) === null) {
 			return null;
 		}
 
-		return reset($msg);
+		if ($decrypt) {
+			return $this->smimeService->decryptDataFetch($message, $userId)->getDecryptedMessage();
+		}
+
+		return $message->getFullMsg();
 	}
 
+	/**
+	 * @param Horde_Imap_Client_Socket $client
+	 * @param string $mailbox
+	 * @param int $uid
+	 * @param string $userId
+	 * @return string|null
+	 *
+	 * @throws DoesNotExistException
+	 * @throws Horde_Imap_Client_Exception
+	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
+	 * @throws Horde_Mime_Exception
+	 * @throws ServiceException
+	 */
 	public function getHtmlBody(Horde_Imap_Client_Socket $client,
-								string $mailbox,
-								int $uid): ?string {
+		string $mailbox,
+		int $uid,
+		string $userId): ?string {
 		$messageQuery = new Horde_Imap_Client_Fetch_Query();
 		$messageQuery->envelope();
 		$messageQuery->structure();
+		$this->smimeService->addEncryptionCheckQueries($messageQuery, true);
 
 		$result = $client->fetch($mailbox, $messageQuery, [
 			'ids' => new Horde_Imap_Client_Ids([$uid]),
@@ -474,6 +533,23 @@ class MessageMapper {
 		}
 
 		$structure = $message->getStructure();
+
+		// Handle S/MIME encrypted message
+		if ($this->smimeService->isEncrypted($message)) {
+			// Encrypted messages have to be fully fetched in order to analyze the structure because
+			// it is hidden (obviously).
+			$fullText = $this->getFullText($client, $mailbox, $uid, $userId);
+
+			// Force mime parsing as decrypted S/MIME payload doesn't have to contain a MIME header
+			$mimePart = Horde_Mime_Part::parseMessage($fullText, ['forcemime' => true ]);
+			$htmlPartId = $mimePart->findBody('html');
+			if (!isset($mimePart[$htmlPartId])) {
+				return null;
+			}
+
+			return $mimePart[$htmlPartId];
+		}
+
 		$htmlPartId = $structure->findBody('html');
 		if ($htmlPartId === null) {
 			// No HTML part
@@ -501,58 +577,31 @@ class MessageMapper {
 		return null;
 	}
 
+	/**
+	 * @deprecated Use getAttachments() instead
+	 *
+	 * @param Horde_Imap_Client_Socket $client
+	 * @param string $mailbox
+	 * @param int $uid
+	 * @param string $userId
+	 * @param array|null $attachmentIds
+	 * @return array
+	 *
+	 * @throws DoesNotExistException
+	 * @throws Horde_Imap_Client_Exception
+	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
+	 * @throws Horde_Mime_Exception
+	 * @throws ServiceException
+	 */
 	public function getRawAttachments(Horde_Imap_Client_Socket $client,
-									string $mailbox,
-									int $uid,
-									?array $attachmentIds = []): array {
-		$messageQuery = new Horde_Imap_Client_Fetch_Query();
-		$messageQuery->structure();
-
-		$result = $client->fetch($mailbox, $messageQuery, [
-			'ids' => new Horde_Imap_Client_Ids([$uid]),
-		]);
-
-		if (($structureResult = $result->first()) === null) {
-			throw new DoesNotExistException('Message does not exist');
-		}
-
-		$structure = $structureResult->getStructure();
-		$partsQuery = $this->buildAttachmentsPartsQuery($structure, $attachmentIds);
-
-		$parts = $client->fetch($mailbox, $partsQuery, [
-			'ids' => new Horde_Imap_Client_Ids([$uid]),
-		]);
-		if (($messageData = $parts->first()) === null) {
-			throw new DoesNotExistException('Message does not exist');
-		}
-
-		$attachments = [];
-		foreach ($structure->partIterator() as $key => $part) {
-			/** @var Horde_Mime_Part $part */
-
-			if (!$part->isAttachment()) {
-				continue;
-			}
-
-			if (!empty($attachmentIds) && !in_array($part->getMimeId(), $attachmentIds, true)) {
-				// We are looking for specific parts only and this is not one of them
-				continue;
-			}
-
-			$stream = $messageData->getBodyPart($key, true);
-			$mimeHeaders = $messageData->getMimeHeader($key, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-			if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-				$part->setTransferEncoding($enc);
-			}
-			$part->setContents($stream, [
-				'usestream' => true,
-			]);
-			$decoded = $part->getContents();
-			fclose($stream);
-
-			$attachments[] = $decoded;
-		}
-		return $attachments;
+		string $mailbox,
+		int $uid,
+		string $userId,
+		?array $attachmentIds = []): array {
+		$attachments = $this->getAttachments($client, $mailbox, $uid, $userId, $attachmentIds);
+		return array_map(static function (Attachment $attachment) {
+			return $attachment->getContent();
+		}, $attachments);
 	}
 
 	/**
@@ -561,34 +610,60 @@ class MessageMapper {
 	 * @param Horde_Imap_Client_Socket $client
 	 * @param string $mailbox
 	 * @param integer $uid
+	 * @param string $userId
 	 * @param array|null $attachmentIds
-	 * @return array[]
+	 * @return Attachment[]
+	 *
+	 * @throws DoesNotExistException
+	 * @throws Horde_Imap_Client_Exception
+	 * @throws Horde_Imap_Client_Exception_NoSupportExtension
+	 * @throws ServiceException
+	 * @throws Horde_Mime_Exception
 	 */
 	public function getAttachments(Horde_Imap_Client_Socket $client,
-									string $mailbox,
-									int $uid,
-									?array $attachmentIds = []): array {
+		string $mailbox,
+		int $uid,
+		string $userId,
+		?array $attachmentIds = []): array {
+		$uids = new Horde_Imap_Client_Ids([$uid]);
+
 		$messageQuery = new Horde_Imap_Client_Fetch_Query();
 		$messageQuery->structure();
+		$this->smimeService->addEncryptionCheckQueries($messageQuery);
 
-		$result = $client->fetch($mailbox, $messageQuery, [
-			'ids' => new Horde_Imap_Client_Ids([$uid]),
-		]);
+		$result = $client->fetch($mailbox, $messageQuery, ['ids' => $uids ]);
 
 		if (($structureResult = $result->first()) === null) {
 			throw new DoesNotExistException('Message does not exist');
 		}
 
 		$structure = $structureResult->getStructure();
-		$partsQuery = $this->buildAttachmentsPartsQuery($structure, $attachmentIds);
+		$messageData = null;
 
-		$parts = $client->fetch($mailbox, $partsQuery, [
-			'ids' => new Horde_Imap_Client_Ids([$uid]),
-		]);
-		if (($messageData = $parts->first()) === null) {
-			throw new DoesNotExistException('Message does not exist');
+		$isEncrypted = $this->smimeService->isEncrypted($structureResult);
+		if ($isEncrypted) {
+			$fullTextQuery = new Horde_Imap_Client_Fetch_Query();
+			$this->smimeService->addDecryptQueries($fullTextQuery);
+
+			$fullTextParts = $client->fetch($mailbox, $fullTextQuery, ['ids' => $uids ]);
+			if (($fullTextResult = $fullTextParts->first()) === null) {
+				throw new DoesNotExistException('Message does not exist');
+			}
+			$decryptedText = $this->smimeService
+				->decryptDataFetch($fullTextResult, $userId)
+				->getDecryptedMessage();
+
+			// Replace opaque structure with decrypted structure
+			$structure = Horde_Mime_Part::parseMessage($decryptedText, [ 'forcemime' => true ]);
+		} else {
+			$partsQuery = $this->buildAttachmentsPartsQuery($structure, $attachmentIds);
+			$parts = $client->fetch($mailbox, $partsQuery, ['ids' => $uids ]);
+			if (($messageData = $parts->first()) === null) {
+				throw new DoesNotExistException('Message does not exist');
+			}
 		}
 
+		/** @var Attachment[] $attachments */
 		$attachments = [];
 		foreach ($structure->partIterator() as $key => $part) {
 			/** @var Horde_Mime_Part $part */
@@ -602,28 +677,153 @@ class MessageMapper {
 				continue;
 			}
 
-			$stream = $messageData->getBodyPart($key, true);
-			$mimeHeaders = $messageData->getMimeHeader($key, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-			if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-				$part->setTransferEncoding($enc);
+			// Encrypted parts were already decoded and their content can be used directly
+			if (!$isEncrypted) {
+				$stream = $messageData->getBodyPart($key, true);
+				$mimeHeaders = $messageData->getMimeHeader($key, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
+					$part->setTransferEncoding($enc);
+				}
+
+				/*
+				 * usestream depends on transfer encoding
+				 *
+				 * Case 1: base64 encoded file
+				 * Base64 stream is copied to a new stream and decoded using a convert.base64-decode stream filter.
+				 *
+				 * Case 2: text file (no transfer encoding)
+				 * Existing stream is reused in Horde_Mime_Part.
+				 *
+				 * To handle both cases:
+				 *
+				 * 1) Horde_Mime_Part.clearContents to close the internal stream (Horde_Mime_Part._contents)
+				 * 2) If $stream is still open, the data was transfer encoded, close it.
+				 *
+				 * Attachment.fromMimePart uses Horde_Mime_Part.getContents and Horde_Mime_Part.getBytes
+				 * and therefore needs an open input stream.
+				 */
+				$part->setContents($stream, [
+					'usestream' => true
+				]);
+				$attachments[] = Attachment::fromMimePart($part);
+				$part->clearContents();
+				if (is_resource($stream)) {
+					fclose($stream);
+				}
+			} else {
+				$attachments[] = Attachment::fromMimePart($part);
+				$part->clearContents();
 			}
-			$part->setContents($stream, [
-				'usestream' => true,
-			]);
-			$attachments[] = [
-				'content' => $part->getContents(),
-				'name' => $part->getName(),
-				'size' => $part->getBytes()
-			];
-			fclose($stream);
 		}
 		return $attachments;
 	}
 
+	/**
+	 * @param Horde_Imap_Client_Base $client
+	 * @param string $mailbox
+	 * @param int $messageUid
+	 * @param string $attachmentId
+	 * @param string $userId
+	 * @return Attachment
+	 *
+	 * @throws DoesNotExistException
+	 * @throws Horde_Imap_Client_Exception
+	 * @throws ServiceException
+	 * @throws Horde_Mime_Exception
+	 */
+	public function getAttachment(Horde_Imap_Client_Base $client,
+		string $mailbox,
+		int $messageUid,
+		string $attachmentId,
+		string $userId): Attachment {
+		// TODO: compare logic and merge with getAttachments()
+
+		$query = new Horde_Imap_Client_Fetch_Query();
+		$query->bodyPart($attachmentId);
+		$query->mimeHeader($attachmentId);
+		$this->smimeService->addEncryptionCheckQueries($query);
+
+		$uids = new Horde_Imap_Client_Ids($messageUid);
+		$headers = $client->fetch($mailbox, $query, ['ids' => $uids]);
+		if (!isset($headers[$messageUid])) {
+			throw new DoesNotExistException('Unable to load the attachment.');
+		}
+
+		/** @var Horde_Imap_Client_Data_Fetch $fetch */
+		$fetch = $headers[$messageUid];
+
+		/** @var Horde_Mime_Headers $mimeHeaders */
+		$mimeHeaders = $fetch->getMimeHeader($attachmentId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+
+		$body = $fetch->getBodyPart($attachmentId);
+
+		$isEncrypted = $this->smimeService->isEncrypted($fetch);
+		if ($isEncrypted) {
+			$fullTextQuery = new Horde_Imap_Client_Fetch_Query();
+			$this->smimeService->addDecryptQueries($fullTextQuery);
+
+			$result = $client->fetch($mailbox, $fullTextQuery, ['ids' => $uids]);
+			if (!isset($result[$messageUid])) {
+				throw new DoesNotExistException('Unable to load the attachment.');
+			}
+			$fullTextResult = $result[$messageUid];
+
+			$decryptedText = $this->smimeService
+				->decryptDataFetch($fullTextResult, $userId)
+				->getDecryptedMessage();
+			$decryptedPart = Horde_Mime_Part::parseMessage($decryptedText, [ 'forcemime' => true ]);
+			if (!isset($decryptedPart[$attachmentId])) {
+				throw new DoesNotExistException('Unable to load the attachment.');
+			}
+
+			$attachmentPart = $decryptedPart[$attachmentId];
+			$body = $attachmentPart->getContents();
+			$mimeHeaders = $attachmentPart->addMimeHeaders();
+		}
+
+		$mimePart = new Horde_Mime_Part();
+
+		// Serve all files with a content-disposition of "attachment" to prevent Cross-Site Scripting
+		$mimePart->setDisposition('attachment');
+
+		// Extract headers from part
+		$contentDisposition = $mimeHeaders->getValue('content-disposition', Horde_Mime_Headers::VALUE_PARAMS);
+		if (!is_null($contentDisposition) && isset($contentDisposition['filename'])) {
+			$mimePart->setDispositionParameter('filename', $contentDisposition['filename']);
+		} else {
+			$contentDisposition = $mimeHeaders->getValue('content-type', Horde_Mime_Headers::VALUE_PARAMS);
+			if (isset($contentDisposition['name'])) {
+				$mimePart->setContentTypeParameter('name', $contentDisposition['name']);
+			}
+		}
+
+		// Content transfer encoding
+		// Decrypted parts are already decoded because they went through the MIME parser
+		if (!$isEncrypted && $tmp = $mimeHeaders->getValue('content-transfer-encoding')) {
+			$mimePart->setTransferEncoding($tmp);
+		}
+
+		/* Content type */
+		$contentType = $mimeHeaders->getValue('content-type');
+		if (!is_null($contentType) && str_contains($contentType, 'text/calendar')) {
+			$mimePart->setType('text/calendar');
+			if ($mimePart->getContentTypeParameter('name') === null) {
+				$mimePart->setContentTypeParameter('name', 'calendar.ics');
+			}
+		} else {
+			// To prevent potential problems with the SOP we serve all files but calendar entries with the
+			// MIME type "application/octet-stream"
+			$mimePart->setType('application/octet-stream');
+		}
+
+		$mimePart->setContents($body);
+		return Attachment::fromMimePart($mimePart);
+	}
+
 	/**
 	 * Build the parts query for attachments
 	 *
-	 * @param $structure
+	 * @param Horde_Mime_Part $structure
 	 * @param array $attachmentIds
 	 * @return Horde_Imap_Client_Fetch_Query
 	 */
@@ -637,7 +837,7 @@ class MessageMapper {
 				continue;
 			}
 
-			if (!empty($attachmentIds) && !in_array($part->getMimeId(), $attachmentIds, true)) {
+			if ($attachmentIds !== [] && !in_array($part->getMimeId(), $attachmentIds, true)) {
 				// We are looking for specific parts only and this is not one of them
 				continue;
 			}
@@ -661,25 +861,32 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function getBodyStructureData(Horde_Imap_Client_Socket $client,
-										 string $mailbox,
-										 array $uids): array {
+		string $mailbox,
+		array $uids,
+		string $emailAddress): array {
 		$structureQuery = new Horde_Imap_Client_Fetch_Query();
 		$structureQuery->structure();
 		$structureQuery->headerText([
 			'cache' => true,
 			'peek' => true,
 		]);
+		$this->smimeService->addEncryptionCheckQueries($structureQuery);
 
 		$structures = $client->fetch($mailbox, $structureQuery, [
 			'ids' => new Horde_Imap_Client_Ids($uids),
 		]);
-
-		return array_map(function (Horde_Imap_Client_Data_Fetch $fetchData) use ($mailbox, $client) {
+		return array_map(function (Horde_Imap_Client_Data_Fetch $fetchData) use ($mailbox, $client, $emailAddress) {
 			$hasAttachments = false;
 			$text = '';
 			$isImipMessage = false;
+			$isEncrypted = false;
+
+			if ($this->smimeService->isEncrypted($fetchData)) {
+				$isEncrypted = true;
+			}
 
 			$structure = $fetchData->getStructure();
+
 			/** @var Horde_Mime_Part $part */
 			foreach ($structure->getParts() as $part) {
 				if ($part->isAttachment()) {
@@ -698,12 +905,11 @@ class MessageMapper {
 			$textBodyId = $structure->findBody() ?? $structure->findBody('text');
 			$htmlBodyId = $structure->findBody('html');
 			if ($textBodyId === null && $htmlBodyId === null) {
-				return new MessageStructureData($hasAttachments, $text, $isImipMessage);
+				return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted, false);
 			}
 			$partsQuery = new Horde_Imap_Client_Fetch_Query();
 			if ($htmlBodyId !== null) {
 				$partsQuery->bodyPart($htmlBodyId, [
-					'decode' => true,
 					'peek' => true,
 				]);
 				$partsQuery->mimeHeader($htmlBodyId, [
@@ -712,7 +918,6 @@ class MessageMapper {
 			}
 			if ($textBodyId !== null) {
 				$partsQuery->bodyPart($textBodyId, [
-					'decode' => true,
 					'peek' => true,
 				]);
 				$partsQuery->mimeHeader($textBodyId, [
@@ -724,28 +929,65 @@ class MessageMapper {
 			]);
 			/** @var Horde_Imap_Client_Data_Fetch $part */
 			$part = $parts[$fetchData->getUid()];
-			$htmlBody = $part->getBodyPart($htmlBodyId);
+			// This is sus - why does this even happen? A delete / move in the middle of this processing?
+			if ($part === null) {
+				return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted, false);
+			}
+
+
+			$htmlBody = ($htmlBodyId !== null) ? $part->getBodyPart($htmlBodyId) : null;
 			if (!empty($htmlBody)) {
 				$mimeHeaders = $part->getMimeHeader($htmlBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
 				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
 					$structure->setTransferEncoding($enc);
+					$structure->setContents($htmlBody);
+					$htmlBody = $this->converter->convert($structure);
 				}
-				$structure->setContents($htmlBody);
-				$html = new Html2Text($structure->getContents());
-				return new MessageStructureData($hasAttachments, trim($html->getText()), $isImipMessage);
+				$mentionsUser = $this->checkLinks($htmlBody, $emailAddress);
+				$html = new Html2Text($htmlBody, ['do_links' => 'none','alt_image' => 'hide']);
+				return new MessageStructureData(
+					$hasAttachments,
+					trim($html->getText()),
+					$isImipMessage,
+					$isEncrypted,
+					$mentionsUser,
+				);
 			}
 			$textBody = $part->getBodyPart($textBodyId);
+
 			if (!empty($textBody)) {
 				$mimeHeaders = $part->getMimeHeader($textBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
 				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
 					$structure->setTransferEncoding($enc);
 					$structure->setContents($textBody);
-					return new MessageStructureData($hasAttachments, $structure->getContents(), $isImipMessage);
+					$textBody = $this->converter->convert($structure);
 				}
-				return new MessageStructureData($hasAttachments, $textBody, $isImipMessage);
+				return new MessageStructureData(
+					$hasAttachments,
+					$textBody,
+					$isImipMessage,
+					$isEncrypted,
+					false,
+				);
 			}
-
-			return new MessageStructureData($hasAttachments, $text, $isImipMessage);
+			return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted, false);
 		}, iterator_to_array($structures->getIterator()));
 	}
+	private function checkLinks(string $body, string $mailAddress) : bool {
+		if (empty($body)) {
+			return false;
+		}
+		$dom = new \DOMDocument();
+		libxml_use_internal_errors(true);
+		$dom->loadHTML($body);
+		libxml_use_internal_errors();
+		$anchors = $dom->getElementsByTagName('a');
+		foreach ($anchors as $anchor) {
+			$href = $anchor->getAttribute('href');
+			if ($href === 'mailto:' . $mailAddress) {
+				return true;
+			}
+		}
+		return false;
+	}
 }
