@@ -3,25 +3,8 @@
 declare(strict_types=1);
 
 /**
- * Mail App
- *
- * @copyright 2022 Anna Larch <anna.larch@gmx.net>
- *
- * @author Anna Larch <anna.larch@gmx.net>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Service;
@@ -51,7 +34,7 @@ class IMipService {
 		LoggerInterface $logger,
 		MailboxMapper $mailboxMapper,
 		MailManager $mailManager,
-		MessageMapper $messageMapper
+		MessageMapper $messageMapper,
 	) {
 		$this->accountService = $accountService;
 		$this->calendarManager = $manager;
@@ -63,7 +46,7 @@ class IMipService {
 
 	public function process(): void {
 		$messages = $this->messageMapper->findIMipMessagesAscending();
-		if (empty($messages)) {
+		if ($messages === []) {
 			$this->logger->info('No iMIP messages to process.');
 			return;
 		}
@@ -73,20 +56,20 @@ class IMipService {
 		// and JOIN with accounts table
 		// although this might not make much of a difference
 		// since there are very few messages to process
-		$mailboxIds = array_unique(array_map(function (Message $message) {
+		$mailboxIds = array_unique(array_map(static function (Message $message) {
 			return $message->getMailboxId();
 		}, $messages));
 
 		$mailboxes = array_map(function (int $mailboxId) {
 			try {
 				return $this->mailboxMapper->findById($mailboxId);
-			} catch (DoesNotExistException | ServiceException $e) {
+			} catch (DoesNotExistException|ServiceException $e) {
 				return null;
 			}
 		}, $mailboxIds);
 
 		// Collect all accounts in memory
-		$accountIds = array_unique(array_map(function (Mailbox $mailbox) {
+		$accountIds = array_unique(array_map(static function (Mailbox $mailbox) {
 			return $mailbox->getAccountId();
 		}, $mailboxes));
 
@@ -102,11 +85,11 @@ class IMipService {
 		foreach ($mailboxes as $mailbox) {
 			/** @var Account $account */
 			$account = $accounts[$mailbox->getAccountId()];
-			$filteredMessages = array_filter($messages, function ($message) use ($mailbox) {
+			$filteredMessages = array_filter($messages, static function ($message) use ($mailbox) {
 				return $message->getMailboxId() === $mailbox->getId();
 			});
 
-			if (empty($filteredMessages)) {
+			if ($filteredMessages === []) {
 				continue;
 			}
 
@@ -114,12 +97,13 @@ class IMipService {
 			// no processing for drafts, sent items, junk or archive
 			if ($account === null
 				|| $account->getMailAccount()->getArchiveMailboxId() === $mailbox->getId()
+				|| $account->getMailAccount()->getSnoozeMailboxId() === $mailbox->getId()
 				|| $account->getMailAccount()->getTrashMailboxId() === $mailbox->getId()
 				|| $account->getMailAccount()->getSentMailboxId() === $mailbox->getId()
 				|| $account->getMailAccount()->getDraftsMailboxId() === $mailbox->getId()
 				|| $mailbox->isSpecialUse(\Horde_Imap_Client::SPECIALUSE_ARCHIVE)
 			) {
-				$processedMessages = array_map(function (Message $message) {
+				$processedMessages = array_map(static function (Message $message) {
 					$message->setImipProcessed(true);
 					return $message;
 				}, $filteredMessages); // Silently drop from passing to DAV and mark as processed, so we won't run into these messages again.
@@ -128,7 +112,7 @@ class IMipService {
 			}
 
 			try {
-				$imapMessages = $this->mailManager->getImapMessagesForScheduleProcessing($account, $mailbox, array_map(function ($message) {
+				$imapMessages = $this->mailManager->getImapMessagesForScheduleProcessing($account, $mailbox, array_map(static function ($message) {
 					return $message->getUid();
 				}, $filteredMessages));
 			} catch (ServiceException $e) {
@@ -138,7 +122,7 @@ class IMipService {
 
 			foreach ($filteredMessages as $message) {
 				/** @var IMAPMessage $imapMessage */
-				$imapMessage = current(array_filter($imapMessages, function (IMAPMessage $imapMessage) use ($message) {
+				$imapMessage = current(array_filter($imapMessages, static function (IMAPMessage $imapMessage) use ($message) {
 					return $message->getUid() === $imapMessage->getUid();
 				}));
 				if (empty($imapMessage->scheduling)) {
