@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Service\Search;
@@ -50,6 +34,9 @@ class SearchQuery {
 	/** @var string[] */
 	private $subjects = [];
 
+	/** @var string[] */
+	private $bodies = [];
+
 	/** @var string[] */
 	private $textTokens = [];
 
@@ -65,6 +52,11 @@ class SearchQuery {
 	/** @var bool */
 	private $hasAttachments = false;
 
+	/** @var bool */
+	private $mentionsMe = false;
+
+	private string $match = 'allof';
+
 	/**
 	 * @return int|null
 	 * @psalm-mutation-free
@@ -80,6 +72,14 @@ class SearchQuery {
 		$this->cursor = $cursor;
 	}
 
+	public function getMatch(): string {
+		return $this->match;
+	}
+
+	public function setMatch(string $match): void {
+		$this->match = $match;
+	}
+
 	/**
 	 * @return Flag[]
 	 * @psalm-mutation-free
@@ -154,16 +154,12 @@ class SearchQuery {
 	public function addSubject(string $subject): void {
 		$this->subjects[] = $subject;
 	}
-
-	/**
-	 * @return string[]
-	 */
-	public function getTextTokens(): array {
-		return $this->textTokens;
+	public function getBodies(): array {
+		return $this->bodies;
 	}
 
-	public function addTextToken(string $textToken): void {
-		$this->textTokens[] = $textToken;
+	public function addBody(string $body): void {
+		$this->bodies[] = $body;
 	}
 
 	/**
@@ -237,4 +233,18 @@ class SearchQuery {
 	public function setHasAttachments(bool $hasAttachments): void {
 		$this->hasAttachments = $hasAttachments;
 	}
+
+	/**
+	 * @return bool
+	 */
+	public function getMentionsMe(): bool {
+		return $this->mentionsMe;
+	}
+
+	/**
+	 * @param bool $hasAttachments
+	 */
+	public function setMentionsMe(bool $mentionsMe): void {
+		$this->mentionsMe = $mentionsMe;
+	}
 }
